; * decoder for FSK modulation supplied by an fm-radio
; * special for FTZ 171 TR 60
; * dynamic polarity detection of 0 and 1

; ------------------------------------------------------------------------

;bugs: no 0-1 swap, when negative

XDEF _FSK

; ULONG pos=FSK(UBYTE *data,ULONG size,ULONG pos,UBYTE *buff)

; pos=	no data-block (pos=0)
;	if pos!=0, call again recrusive with pos
;	the data block is valid! call again to process more

; *data=pointer to data of unsigned samples
; size=	size of sample data
; pos=  offset from *data (for the first time, call with 0)
; *buff=buffer (size is 19 bytes)
;	the buffer contains the binary data

; ------------------------------------------------------------------------

rate=54536	; sampling rate (use not higher than uword)
;rate=48000
bits=5280	; bit rate for each binary digit (use not higher than uword)

sync1=%000100101110001001011100010010	;positive sync
sync2=%111011010001110110100011101101	;negative sync
;soff=-1827+3654;sync offset for sampler rate (48000) (bust be added to the sum of the sync buffer, to get the correct position)
soff=2075 ; sync offset for sampler rate (54536)

; ------------------------------------------------------------------------

;test routine

a:		move.l	#$80,pos
		move.l	#2024,size
		move.l	#testspl,data
		move.l	#testraw,buff
		jsr	fsk
		rts

testspl:	blk.b	2024
>extern"ds09:-test.OgK",testspl,2024
testraw:	blk.b	1+70+80
even

; ------------------------------------------------------------------------

_FSK:
		move.l	4(a7),data
		move.l	8(a7),size
		move.l	12(a7),pos
		move.l	16(a7),buff

		movem.l d0-d7/a0-a6,-(a7)

		bsr	fsk

		movem.l (a7)+,d0-d7/a0-a6

		move.l	pos,d0

		rts

; ------------------------------------------------------------------------

fsk:
		;prepare register
		move.l	data,a0		; a0=current sample pos
		add.l	pos,a0		; add offset (pos)
		move.l	size,d7
		sub.l	pos,d7	; sub offset from total samples
		tst.l	d7
		beq	end		; end if no more data is about to read
		subq	#1,d7		; d7=sample count down
		move.l	buff,a2		; a2=buffer of output
		move.l	#syncbuff,a3	; a3= sync buffer
		move.w	#0,valide

loop:		;read data
		move.b	(a0)+,d0	; read signed value to d0.w
		btst	#7,d0		; check sign
		bne	negative

		;positive process
		tst.w	lastsign
		beq	stay
		move.w	scount,d4	; set peak position
		moveq	#0,d2		; set 1 for bits
		bsr	calcbin		; calculate binary distance
		move.w	#0,lastsign
		bra	stay

negative:	;negative process
		tst.w	lastsign
		bne	stay
		move.w	scount,d4	; set peak position
		moveq	#1,d2		; set 0 for bits
		bsr	calcbin		; calculate binary distance
		move.w	#1,lastsign

stay:
		add.l	#1,pos
		tst.w	valide		; test if data in buffer is valid and quit
		bne	earlyend

		add.w	#1,scount	; count samples
		dbf	d7,loop		; loop all samples

end:		move.l	#0,pos		; pos=0: no data
earlyend:	rts

; ------------------------------------------------------------------------

calcbin:
		tst.w	sync		; check if sync is enabled
		bne	syncbit		; determine bits from sync value

		;calc bit without sync
		cmp.w	lastpos,d4
		beq	endcalc		; if no change
		move.w	d4,d1
		sub.w	lastpos,d1	; d1=samples from last peak
		mulu	#bits,d1
		add.l	#rate/2,d1	; add 0.5 for rounding up
		divu	#rate,d1	; d1=number of bits exeeded
		tst.w	d1
		bne.w	nonull
		moveq	#1,d1		; set always one bit minimum
nonull:		subq	#1,d1

;		;check if in sync
;		tst.w	sync		; check if sync is enabled
;		bne	insync

		; save bit into table
		move.w	snum,d5
		and.w	#%11110,d5
		move.w	d4,(a3,d5.w)
		add.w	#2,snum

		; put bit to shifter
bitloop:	move.l	shift,d3	; get shifter
		lsl.l	#1,d3		;
		add.b	d2,d3		; shift new bit in
		and.l	#%00111111111111111111111111111111,d3 ; check only 30 bit
		move.l	d3,shift	;

		; check sync
	tst.w	sync		; check if sync is enabled
	bne	insync
		cmp.l	#sync1,d3	; check if sync is found
		beq	syncfound
		cmp.l	#sync2,d3	; check if sync is found
		bne	endbitloop

		; establish sync
syncfound:	move.w	#1,sync		; set sync on
		move.w	#0,bnum		; set first bit
		; calc spos
		moveq	#0,d5
		moveq	#0,d3
addbuf:		add.w	(a3,d5.w),d3	; add all buffer values to d3
		sub.w	d4,d3		; substract current position
		addq	#2,d5
		cmp.w	#16*2,d5
		bne	addbuf
		add.w	#soff,d3	; add negative offset
		asr.w	#4,d3		; d3=correcting offset to d4
		neg.w	d3		; use error against d4 (d3=d4-d3)
		add.w	d4,d3
		move.w	d3,spos		; spos=syncron base value
		bra	endbitloop

		; write bit
insync:		move.w	bnum,d0
		or.b	#'0',d2		; make ascii
		move.b	d2,(a2,d0.w)	; write bit
		add.w	#1,bnum

		; stop if last bit was written
		cmp.w	#1+70+80,bnum
		bne	endbitloop	; endbitloop, if not all bitts
		move.w	#0,sync		; end of sync
		move.l	#0,shift	; clear shifter to avoid false sync detect
		move.w	#1,valide

endbitloop:	dbf	d1,bitloop

endcalc:	move.w	d4,lastpos	; set new 'lastpos'
		rts

syncbit:	;calc bits with sync
		move.w	d4,d1
		sub.w	spos,d1		; d1=samples from sync start
		muls	#bits/2,d1
		add.l	#rate/4,d1	; add 0.5 for rounding up
		divs	#rate/2,d1	; d1=number of bitts since sync
	
		sub.w	bnum,d1		; d1=number of new bits
		tst.w	d1
		beq	endcalc		; if no new bitts
		btst	#15,d1
		bne	endcalc
		bra	nonull		; continue with d1=bits

; ------------------------------------------------------------------------

data:		dc.l	0		; pointer to sample block
size:		dc.l	0		; size of sample block
pos:		dc.l	0		; offset from sample block
buff:		dc.l	0		; pointer to buffer (1+70+80)

lastsign:	dc.w	0		; 1=last sample was negative
valide:		dc.w	0		; if not 0, data buffer is valide
scount:		dc.w	0		; counter of samples (for duration determination)
lastpos:	dc.w	0		; scount value of last peak but one
shift:		dc.l	0		; register of bits to determine sync
sync:		dc.w	0		; flag is not 0, if sync was detected and data is about to read
bnum:		dc.w	0		; current number of frame-bits read
snum:		dc.w	0		; byte-offset in sync buffer (*2)
syncbuff:	blk.w	16		; 16 word buffer
spos:		dc.w	0		; bse position when in sync

; ------------------------------------------------------------------------

