; * decoder for FSK modulation supplied by an fm-radio
; * special for FTZ 171 TR 60
; * dynamic polarity detection of 0 and 1

;bugs: no 0-1 swap, when negative

XDEF _FSK_FM,_QUALITY

; UBYTE pos=FSK_FM(UBYTE *data,ULONG size,ULONG pos,UBYTE *buff)

; pos=	no data-block (pos=0)
;	if pos!=0, call again recrusive with pos
;	the data block is valid! call again to process more

; *data=pointer to data of unsigned samples
; size=	size of sample data
; pos=  offset from *data (for the first time, call with 0)
; *buff=buffer (size is 19 bytes)
;	the buffer contains the binary data

; ULONG QUALITY = quality of signal (0=exellent)

rate=48000	; sampling rate (use not higher than uword)
bits=5280	; bit rate for each binary digit (use not higher than uword)
dist=30		; value of change to detect peak
		; with volume 5, no bass, full treble, values from 10-70 work

sync1=%000100101110001001011100010010	;positive sync
sync2=%111011010001110110100011101101	;negative sync
soff=-1827+3654;sync offset (bust be added to the sum of the sync buffer, to get the correct position)

;test routine

a:		move.l	#$80,pos
		move.l	#2024,size
		move.l	#$500000,data
		move.l	#testraw,buff
		jsr	fsk_fm
		rts

testspl:	blk.b	2024
>extern"sound:test.OgK",$500000,2024
testraw:	blk.b	1+70+80
even

;------------

_FSK_FM:
		move.l	4(a7),data
		move.l	8(a7),size
		move.l	12(a7),pos
		move.l	16(a7),buff

		movem.l d0-d7/a0-a6,-(a7)

		bsr	fsk_fm

		movem.l (a7)+,d0-d7/a0-a6

		move.l	pos,d0

		rts

fsk_fm:
		move.l	data,a0		; a0=current sample pos
		add.l	pos,a0		; add offset (pos)
		move.l	size,d7
		sub.l	pos,d7	; sub offset from total samples
		tst.l	d7
		beq	end		; end if no more data is about to read
		subq	#1,d7		; d7=sample count down
		move.l	buff,a2		; a2=buffer of output
		move.l	#syncbuff,a3	; a3= sync buffer
		move.w	#0,valide

loop:
		move.w	#$0100,d0
		move.b	(a0)+,d0	; read unsigned value to d0.w+256

		cmp.w	hpeak,d0	; set hpeak, if higher
		bcs	nohi
		move.w	d0,hpeak
		move.w	scount,hpos
nohi:
		cmp.w	lpeak,d0	; set lpeak, if lower
		bcc	nolo
		move.w	d0,lpeak
		move.w	scount,lpos
nolo:
					; if curve goes down twice as much, the peak is 0 from the last, so a change of 0 must be ignored
		move.w	hpeak,d1	; determine curve goes down (peak was high)
		sub.w	d0,d1
		btst	#15,d1
		bne	nohpeak		; skip, if negative
		cmp.w	#dist,d1
		bcs	nohpeak		; skip, if value is not high enough

		move.w	d0,hpeak	; reset hpeak
		move.w	d0,lpeak	; reset lpeak
		move.w	hpos,d4		; set peak position
		moveq	#0,d2		; set 1 for bits
		bsr	calcbin		; calculate binary distance
;		move.w	scount,lpos
nohpeak:
		move.w	d0,d1		; determine curve goes up (peak was low)
		sub.w	lpeak,d1
		btst	#15,d1
		bne	nolpeak		; skip, if negative
		cmp.w	#dist,d1
		bcs	nolpeak		; skip, if value is not high enough

		move.w	d0,hpeak	; reset hpeak
		move.w	d0,lpeak	; reset lpeak
		move.w	lpos,d4		; set peak position
		moveq	#1,d2		; set 0 for bits
		bsr	calcbin		; calculate binary distance
nolpeak:
		add.l	#1,pos
		tst.w	valide		; test if data in buffer is valid and quit
		bne	earlyend

		add.w	#1,scount	; count samples
		dbf	d7,loop		; loop all samples

end:		move.l	#0,pos		; pos=0: no data
earlyend:	rts

calcbin:
		tst.w	sync		; check if sync is enabled
		bne	syncbit		; determine bitts from sync value
		cmp.w	lastpos,d4
		beq	endcalc		; if no change
		move.w	d4,d1
		sub.w	lastpos,d1	; d1=samples from last peak
		mulu	#bits,d1
		add.l	#rate/2,d1	; add 0.5 for rounding up
		divu	#rate,d1	; d1=number of bits exeeded
		tst.w	d1
		bne.w	nonull
		moveq	#1,d1		; set always one bit minimum
nonull:		subq	#1,d1

		; save bit into table
		move.w	snum,d5
		and.w	#%11110,d5
		move.w	d4,(a3,d5.w)
		add.w	#2,snum

		; put bit to shifter
bitloop:	move.l	shift,d3	; get shifter
		lsl.l	#1,d3		;
		add.b	d2,d3		; shift new bit in
		and.l	#%00111111111111111111111111111111,d3 ; check only 30 bit
		move.l	d3,shift	;
	add.w	#1,testlauf
	cmp.w	#32+5+3,testlauf
	bne notestbreak
;	illegal
	notestbreak:

		; check sync
		tst.w	sync		; check if sync is enabled
		bne	insync
		cmp.l	#sync1,d3	; check if sync is found
		beq	syncfound
		cmp.l	#sync2,d3	; check if sync is found
		bne	endbitloop

		; establish sync
syncfound:	move.w	#1,sync		; set sync on
		move.w	#0,bnum		; set first bit
		move.l	#0,_quality
		; calc spos
		moveq	#0,d5
		moveq	#0,d3
addbuf:		add.w	(a3,d5.w),d3	; add all buffer values to d3
		sub.w	d4,d3		; substract current position
		addq	#2,d5
		cmp.w	#16*2,d5
		bne	addbuf
		add.w	#soff,d3	; add negative offset
		asr.w	#4,d3		; d3=correcting offset to d4
;	ext.l	d3
;	move.w	d3,_quality+2	; use to display correct soff value
		neg.w	d3		; use error against d4 (d3=d4-d3)
		add.w	d4,d3
		move.w	d3,spos		; spos=syncron base value
		bra	endbitloop

		; write bit
insync:		move.w	bnum,d0
		or.b	#'0',d2		; make ascii
		move.b	d2,(a2,d0.w)	; write bit
		add.w	#1,bnum

		; stop if last bit was written
		cmp.w	#1+70+80,bnum
		bne	endbitloop	; endbitloop, if not all bitts
		move.w	#0,sync		; end of sync
		move.l	#0,shift	; clear shifter to avoid false sync detect
		move.w	#1,valide

endbitloop:	dbf	d1,bitloop

endcalc:	move.w	d4,lastpos	; set new 'lastpos'
		rts

syncbit:	move.w	d4,d1
		sub.w	spos,d1		; d1=samples from sync start
		muls	#bits/2,d1
		add.l	#rate/4,d1	; add 0.5 for rounding up
		divs	#rate/2,d1	; d1=number of bitts since sync

		;calc error
		move.w	d1,d3
		muls	#rate/2,d3
		divs	#bits/2,d3
		add.w	spos,d3
		sub.w	d4,d3		; d3=diff
		btst	#15,d3
		beq	nodiffneg
		neg.w	d3
nodiffneg:	add.w	d3,_quality+2
	
		sub.w	bnum,d1		; d1=number of new bits
		tst.w	d1
		beq	endcalc		; if no new bitts
		btst	#15,d1
		bne	endcalc
		bra	nonull		; continue with d1=bits


data:		dc.l	0		; pointer to sample block
size:		dc.l	0		; size of sample block
pos:		dc.l	0		; offset from sample block
buff:		dc.l	0		; pointer to buffer (1+70+80)

valide:		dc.w	0		; if not 0, data buffer is valide
scount:		dc.w	0		; counter of samples (for duration determination)
hpeak:		dc.w	0		; high peak level (highest value)
hpos:		dc.w	0		; scount value of high peak
lpeak:		dc.w	0		; low peak level (lowest value)
lpos:		dc.w	0		; scount value of low peak
lastpos:	dc.w	0		; scount value of last peak but one
shift:		dc.l	0		; register of bits to determine sync
sync:		dc.w	0		; flag is not 0, if sync was detected and data is about to read
bnum:		dc.w	0		; current number of frame-bits read
snum:		dc.w	0		; byte-offset in sync buffer (*2)
syncbuff:	blk.w	16		; 16 word buffer
spos:		dc.w	0		; bse position when in sync
_quality:	dc.l	0		; signal quality

testlauf: dc.w 0
