/* - this routine reads data from toccata
   - sound data is converted to binary
   - (binary will be error corrected)
   - (raw data will be interpreted) */

/*#define SAMPLER /* if not defined, toccata is used */

#include <dos.h>
#include <stdio.h>
#include <time.h>
#include <proto/exec.h>
#include <proto/dos.h>
#include <exec/devices.h>
#include <exec/libraries.h>
#include <utility/tagitem.h>
#ifndef SAMPLER
#include <libraries/toccata.h>
#include <clib/toccata_protos.h>
#include <pragmas/toccata_pragmas.h>
#endif
#include <string.h>

#ifdef SAMPLER
extern UBYTE *SCAN(VOID);
#endif
extern ULONG FSK(UBYTE *,ULONG,ULONG,UBYTE *);

#ifndef SAMPLER
struct ToccataBase *ToccataBase=0;
#endif
struct Window *window=0;

#define BUFSIZE 512*20

#ifdef SAMPLER
#define RAW_TEXT dummy()
#define ACTION_TEXT dummy()
#define VAN_TEXT dummy()
#define WARN_TEXT dummy()
#define INTER_TEXT dummy()
#endif
#ifndef SAMPLER
#define RAW_TEXT printf("%c[31m",27)
#define ACTION_TEXT printf("%c[32m",27)
#define VAN_TEXT printf("%c[34m",27)
#define WARN_TEXT printf("%c[35m",27)
#define INTER_TEXT printf("%c[36m",27)
#endif
#define BEEP printf("%c",7)

#ifndef SAMPLER
UBYTE buf[64*BUFSIZE];
#endif
#ifdef SAMPLER
UBYTE *buf;
#endif
UBYTE raw[1+70+80+1];

UBYTE frame[70+1];
ULONG pos=0;
char  func_result[256];
char  datat[1024];
int   func_value[32];
int   ParNum;
BOOL  brk=FALSE;
char  MODE_LIN='*';
char  MODE_ERR='*';
char  MODE_DAT='*';
char  MODE_INT='*';
char  MODE_TIM='*';
char  MODE_ACT='*';
char  MODE_CAP=' ';
char  MODE_OUT='*';
char  *waitpoint[]={" |*  |"," | * |"," |  *|"," | * |"};
char  Capture[256]="ram:C-Netz.Cap";

ULONG wring=0;		/* value 0-19 for write in ring buffer */
ULONG rring=0;		/* value 0-19 for read in ring buffer */
ULONG oring=0;		/* ring buffer before delay*/

extern char CTab[32768];

VOID dummy(VOID) {}

#ifndef SAMPLER

BOOL CB_Save(UBYTE *Data, ULONG Size);

ULONG TocTags[] = {
	(TT_BufferPri),	2,
	(TT_IoPri),	20 /*1*/,
	(TT_IrqPri),	105,
	(TT_Frequency),	48000,
	(TT_BufferSize),BUFSIZE,
	(TT_Save),	(ULONG)CB_Save,
	(TT_Mode),	TMODE_LINEAR_8,
    	(TAG_DONE) };

ULONG TocPat[] = {
	(PAT_Input),	TINPUT_Aux1,
	(TAG_DONE) };

#endif

char *Power[] = {
	"50-125mW",
	"0,5-1W  ",
	"4-8W    ",
	"10-20W  " };

char *Genau[] = {
	"exakt   ",
	"ungenau " };

char *Pegel[] = {
	"P0    - ",
	"P0 -2dB ",
	"P0  0dB ",
	"P0  2dB ",
	"P0  4dB ",
	"P0  8dB ",
	"P0 11dB ",
	"P0 15dB " };

char *Aufbau[] = {
	"Ei.,Ve. ",
	"Ei.,--- ",
	"---,Ve. ",
	"---,--- " };

char *Wert[] = {
	"Entfern ",
	"Pegel   " };

char *Entf[] = {
	"  0km   ",
	"  2km   ",
	"2,5km   ",
	"  3km   ",
	"  4km   ",
	"  5km   ",
	"  6km   ",
	"  7km   ",
	"  8km   ",
	" 10km   ",
	" 12km   ",
	" 14km   ",
	" 16km   ",
	" 20km   ",
	" 25km   ",
	" 30km   " };

char *Ausl[] = {
	"gassenb.",
	"tln-bes.",
	"funktec.",
	"-Illegal" };

char *Kenn[] = {
	"Test    ",
	"Normal  ",
	"Vorzug  ",
	"Priorit." };

char *Mitt[] = {
	" 2      ",
	" 4      ",
	" 8      ",
	"16      ",
	"32      ",
	"64      ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal ",
	"Illegal " };

char Digit[] = {
	'0','1','2','3','4','5','6','7',
	'8','9','?','*','#','?','?','?' };


void Func_A(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_B(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"invers  ");
	else	sprintf(func_result,"klar    ");
}

void Func_C(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"in 30sek");
	else	sprintf(func_result,"-       ");
}

void Func_D(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_E(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_F(void)
{
	sprintf(func_result,"%3d     ",func_value[ParNum]);
}

void Func_G(void)
{
	sprintf(func_result,"+1 Einh.",func_value[ParNum]);
}

void Func_H(void)
{
	int f;
	switch (func_value[ParNum]&1)
	{
	  case 1:
		f=4657500-((func_value[ParNum]+1)/2*100);
		break;
	  case 0:
		f=4657500-(func_value[ParNum]/2*125);
		break;
	}
	sprintf(func_result,"%7dk",f);
}

void Func_I(void)
{
	sprintf(func_result,"%d       ",func_value[ParNum]);
}

void Func_J(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"erhhen ");
	else	sprintf(func_result,"erniedr.");
}

void Func_K(void)
{
	Func_H();
}

void Func_L(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"Wiederh.");
	else	sprintf(func_result,"Spontan.");
}

void Func_M(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"   Zeit.");
	else	sprintf(func_result,"Sonderf.");
}

void Func_N(void)
{
	sprintf(func_result,"%d       ",func_value[ParNum]);
}

void Func_P(void)
{
	sprintf(func_result,"%s",Power[func_value[ParNum]]);
}

void Func_Q(void)
{
	sprintf(func_result,"%d       ",func_value[ParNum]);
}

void Func_R(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"Ja      ");
	else	sprintf(func_result,"Nein    ");
}

void Func_S(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"Sonderr.");
	else	sprintf(func_result,"Normal  ");
}

void Func_T(void)
{
	sprintf(func_result,"%05d   ",func_value[ParNum]);
}

void Func_U(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_V(void)
{
	sprintf(func_result,"%5d   ",func_value[ParNum]);
}

void Func_W(void)
{
	sprintf(func_result,"%5d   ",func_value[ParNum]);
}

void Func_X(void)
{
	int x=66,i=0;
	UBYTE Ziffer[16];

	while(i<16)
	{
		Ziffer[i++]=((frame[x]-'0')<<3)+((frame[x+1]-'0')<<2)+((frame[x+2]-'0')<<1)+(frame[x+3]-'0');
		x-=4;
	}
	if (i=Ziffer[0])
	{
		x=0;
		while (x<i)
		{
			func_result[x]=Digit[Ziffer[x+1]];
			x++;
		}
		func_result[x]=0;
	} else
	{
		x=0;
		while (x<16)
		{
			func_result[x]=Digit[Ziffer[x]];
			x++;
		}
	}
}

void Func_Z(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_a(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_b(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"Chip-Ka.");
	else	sprintf(func_result,"Magnet-K");
}

void Func_c(void)
{
	sprintf(func_result,"%s",Ausl[func_value[ParNum]]);
}

void Func_d(void)
{
	sprintf(func_result,"%s",Genau[func_value[ParNum]]);
}

void Func_e(void)
{
	sprintf(func_result,"%3d     ",func_value[ParNum]);
}

void Func_f(void)
{
	sprintf(func_result,"%s",Pegel[func_value[ParNum]]);
}

void Func_g(void)
{
	sprintf(func_result,"%d       ",func_value[ParNum]);
}

void Func_h(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_i(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_j(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_k(void)
{
	sprintf(func_result,"%s",Kenn[func_value[ParNum]]);
}

void Func_l(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"An      ");
	else	sprintf(func_result,"Aus     ");
}

void Func_m(void)
{
	sprintf(func_result,"%s",Mitt[func_value[ParNum]]);
}

void Func_n(void)
{
	sprintf(func_result,"%s",Mitt[func_value[ParNum]]);
}

void Func_o(void)
{
	sprintf(func_result,"%s",frame);
}

void Func_p(void)
{
	sprintf(func_result,"%s",Wert[func_value[ParNum]]);
}

void Func_q(void)
{
	sprintf(func_result,"%s",frame);
}

void Func_r(void)
{
	sprintf(func_result,"%s",Entf[func_value[ParNum]]);
}

void Func_s(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"ungltig");
	else	sprintf(func_result,"gltig  ");
}

void Func_t(void)
{
	if (func_value[ParNum])
		sprintf(func_result,"Test-Tel");
	else	sprintf(func_result,"Normal  ");
}

void Func_u(void)
{
	sprintf(func_result,"%2d      ",func_value[ParNum]);
}

void Func_v(void)
{
	sprintf(func_result,"%s",Aufbau[func_value[ParNum]]);
}

void Func_y(void)
{
	sprintf(func_result,"%s",4-func_value[ParNum]);
}

struct Parameter {
	char	ID;
	char	*Name;
	void (*func)(void);
	} Parameter[] = {
	'A',"FuZ-FuVSt-Nr.  ",(APTR)Func_A,
	'B',"Sprachverschl. ",(APTR)Func_B,
	'C',"Gesprchsende  ",(APTR)Func_C,
	'D',"Tln-Gruppensp. ",(APTR)Func_D,
	'E',"Anz.gesp.Grupp.",(APTR)Func_E,
	'F',"FuZ-Rest-Nr.   ",(APTR)Func_F,
	'G',"Gebhrenstand  ",(APTR)Func_G,
	'H',"OgK-Vorschlag  ",(APTR)Func_H,
	'I',"FuZ-Nationalit.",(APTR)Func_I,
	'J',"Sendeleist.anp.",(APTR)Func_J,
	'K',"Frequenz Nr.   ",(APTR)Func_K,
	'L',"Sig.art. im OgK",(APTR)Func_L,
	'M',"OgK-Verkehrsan.",(APTR)Func_M,
	'N',"FuTln-National.",(APTR)Func_N,
	'P',"Sendeleist. OgK",(APTR)Func_P,
	'Q',"Kartenkennung  ",(APTR)Func_Q,
	'R',"Durch. berbel.",(APTR)Func_R,
	'S',"Sonderruf      ",(APTR)Func_S,
	'T',"FuTln-Rest-Nr. ",(APTR)Func_T,
	'U',"FuTln-HeimFuVSt",(APTR)Func_U,
	'V',"Sicherungs-Code",(APTR)Func_V,
	'W',"WS-Kennung     ",(APTR)Func_W,
	'X',"Wahlziffern    ",(APTR)Func_X,
	'Z',"Zeitschlitz Nr.",(APTR)Func_Z,
	'a',"Grenzw. Ausls.",(APTR)Func_a,
	'b',"Chipkart. Kenn.",(APTR)Func_b,
	'c',"Auslsgrnde   ",(APTR)Func_c,
	'd',"Bed. Genauigk. ",(APTR)Func_d,
	'e',"Entfernung     ",(APTR)Func_e,
	'f',"Unt. Pegelwert ",(APTR)Func_f,
	'g',"Nachbarsch.Pri.",(APTR)Func_g,
	'h',"Hersteller Ken.",(APTR)Func_h,
	'i',"Hardware Kenn. ",(APTR)Func_i,
	'j',"Software Kenn. ",(APTR)Func_j,
	'k',"Kennung FuFSt  ",(APTR)Func_k,
	'l',"Authentificat. ",(APTR)Func_l,
	'm',"Mittel. Ausls.",(APTR)Func_m,
	'n',"Mittel. Umsch. ",(APTR)Func_n,
	'o',"Zufallszahl    ",(APTR)Func_o,
	'p',"Bewertung (P,E)",(APTR)Func_p,
	'q',"Auth.parameter ",(APTR)Func_q,
	'r',"Entfern. FuFSt ",(APTR)Func_r,
	's',"Glt. Geb.stand",(APTR)Func_s,
	't',"Test-FuTelG    ",(APTR)Func_t,
	'u',"Grenzw. Umsch. ",(APTR)Func_u,
	'v',"Vermitt. Sperre",(APTR)Func_v,
	'y',"Authent. Redun.",(APTR)Func_y,
	0  ,"" };

char *Funkdaten[] = {
      /* 8888888877777777666666665555555544444444333333332222222211111111<>text   */
	"-bRL-QQQVVVVVVVVVVVVVVVVIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-EM(R)   Erstmeldung",
	"-bRL-QQQVVVVVVVVVVVVVVVVIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-UM(R)   Umbuchantrag",
	"SbRL-QQQVVVVVVVVVVVVVVVVIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-UWG(R)  Umbuchantrag bei Warteschlange (gehende Verbindung)",
	"--RL-----hhhhhiiiiijjjjjIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-ATO(R)  Auslsen des FuTelG im OgK-Betrieb bei WS",
	"--RL--WW-hhhhhiiiiijjjjjIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-VWG(R)  Verbindungswunsch gehend",
	"--RL-----hhhhhiiiiijjjjjIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-SRG(R)  Sonderruf (Notruf)",
	"SbRL-QQQVVVVVVVVVVVVVVVVIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-NUG(R)  Verbindungswunsch gehend bei Nachbarschaftsuntersttzung",
	"-bRL-QQQVVVVVVVVVVVVVVVVIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-UWK(R)  Umbuchantrag bei Warteschlange (kommende Verbindung)",
	"------------------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-MFT(M)  Meldung: Funktelefonteilnehmer",
	"________________________________________________________________<-Illegal ",
	"XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX<-WUE(M)  Wahlbertragung",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"------dJ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-BEL(K)  Belegung",
	"------dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-VH(K)   Verbindung halten",
	"------dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-RTAQ(K) Quittung Rufton anschalten",
	"------dJBB------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-AH(K)   Abhebe-Signal",
	"------dJBBCt----eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-VH(V)   Verbindung halten",
	"------dJ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-AT(K)   Auslsen durch Funktelefonteilnehmer",
	"------dJBBC-------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-AT(V)   Auslsen durch Funktelefonteilnehmer",
	"------dJBB------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-DSQ(K)  Durchschalten Quittung",
	"------dJBBCt----eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-USAI(V) Umschaltantrag intern",
	"------dJBBCt----eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-USAE(V) Umschaltantrag extern",
	"------dJBB--------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT<-USTLN(K)Umschalten Funktelefonteilnehmer",
	"oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo<-ZFZQ(K) Zufallszahlquittung",
	"qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq<-AP(K)   Autorisierungsparameter",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"________________________________________________________________<-Illegal ",
	"PP-MMMMMDDDDEEEE------HHHHHHHHHHFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->MA(M)   Meldeaufruf",
	"PPdZZZZZ------KKKKKKKKKKIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VAK(R)  Verbindungsaufbau kommend",
	"________________________________________________________________->Illegal ",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->EBQ(R)  Einbuchquittung",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->UBQ(R)  Umbuchquittung",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->WSK(R)  Wartescglange kommend",
	"PP-MMMMMDDDDEEEE------HHHHHHHHHHFFFFFFFF------------------------->MLR(M)  Melde-Leer-Ruf",
	"PPdZZZZZffflvvWW------yyIIIAAAAAFFFFFFFFkkgprrrrmmmmnnnnuuuuaaaa->LR(R)   Leer-Ruf",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->ATQ(R)  Quittung fr Auslsen des FuTelG im OgK-Betrieb",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->SAR(R)  Sperraufruf",
	"PP-MMMMMDDDDEEEE------HHHHHHHHHHFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->WAF(M)  Wahlaufforderung",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->WBP(R)  Wahlbesttigung positiv",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->WBN(R)  Wahlbesttigung negativ",
	"PPdZZZZZ----------------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->WWBP(R) Wahlbesttigung positiv in Warteschlange",
	"PPdZZZZZ------KKKKKKKKKKIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VAG(R)  Verbindungsaufbau gehend",
	"PPdZZZZZ------cc--------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VA(R)   Vorzeitiges Auslsen",
/*48*/	"PP----dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->BQ(K)   Belegungsquittung",
	"PP----dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VHQ(K)  Quittung Verbindung halten",
	"PP----dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->RTA(K)  Rufton anschalten",
	"PP----dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->AHQ(K)  Abhebe-Quittierung",
	"PP----dJ--C-----eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VHQ1(V) Verbindung halten Quittung 1",
	"PP----dJ--CsGGGGGGGGGGGGIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->VHQ2(V) Verbindung halten Quittung 2",
	"PP----dJ------cc--------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->AF(K)   Auslsen durch FuFSt in konzentr. Signalisierung",
	"PP----dJ------cc--------IIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->AF(V)   Auslsen durch FuFSt in verteilter Signalisierung",
	"PP----dJ--------eeeeeeeeIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->DSB(K)  Durchschaltung",
	"PP----dJ------KKKKKKKKKKIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->DSBI(V) Umschaltbefehl intern (neuer SpK in der gleichen FuZ)",
	"PP----dJ------KKKKKKKKKKIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->USF(K)  Umschalten FuFst",
	"PP----dJ------KKKKKKKKKKIIIAAAAAFFFFFFFFNNNUUUUUTTTTTTTTTTTTTTTT->USBE(V) Umschaltbefehl extern (neuer SpK in einer anderen Funkzelle)",
	"oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo->ZFZ(K)  Zufallszahl",
	"________________________________________________________________->Illegal ",
	"________________________________________________________________->Illegal ",
	"________________________________________________________________->Illegal " };


char out[1024];
void print( void )
{
	/* function to print the out text to stdout and/or capture file */
	FILE *fp;
	if (MODE_CAP=='*')
	{
		if(fp=fopen(Capture,"a"))
		{
			fprintf(fp,out);
			fclose(fp);
		} else
		{
			WARN_TEXT;
			printf("<Capture kann nicht geschrieben werden!>");
		}
	}
	if (MODE_OUT=='*')
	{
		printf(out);
	}
}

void ProcessPar(int v,char c)
{
	int x=0;
	void	(*func)(void);

	if (c=='-')
	{
		return;
	}
	while(Parameter[x].ID != c)
	{
		if (Parameter[x].ID==0)
		{
			return;
		}
		x++;
	}
	func_value[ParNum]=v;
	func=Parameter[x].func;
	func();
#ifdef SAMPLER
	if (((ParNum / 3) * 3)==ParNum)
#endif
#ifndef SAMPLER
	if (((ParNum / 4) * 4)==ParNum)
#endif
	{
		sprintf(out,"\n  ");strcat(datat,out);
	}
	sprintf(out,"|%s:%s",Parameter[x].Name,func_result);strcat(datat,out);
	ParNum++;
}

void ProcessSample(void)
{
	struct tm *tp;
	time_t t;
	UBYTE OP_code;
	int x,y,f,fail,warn,ff;
	char c;
	char erro[11];

	pos=0;
#ifndef SAMPLER
	while (pos=FSK(buf+(BUFSIZE*rring),BUFSIZE,pos,raw))
#endif
#ifdef SAMPLER
	if (buf=SCAN())
	while (pos=FSK(buf,4000,pos,raw))
#endif
	{
		/*invert data if negative*/

		if (raw[0]=='0')
		{
			x=0;
			while (x<(150+1))
			{
				raw[x]='0'+'1'-raw[x];
				x++;
			}
		}

		/* decode frame */

		fail=warn=0;
		y=0;
		while (y<10)
		{
			f=0;
			x=0;
			while (x<7)
			{
				f=(f*2)+(raw[61-(x*10)+y]=='1');
				x++;
			}
			x=0;
			while (x<8)
			{
				f=(f*2)+(raw[141-(x*10)+y]=='1');
				x++;
			}
			ff=CTab[f];
			if ((f/256)!=ff)
			{
				if (ff==-1)
				{
					erro[y]='*';
					fail=1;
				} else
				{
					erro[y]='';
					warn++;
				}
			} else
			{
				erro[y]=' ';
			}
			/*f=f/256;*/f=ff;
			frame[69-7*y-6]='0'+((f & 64)>0);
			frame[69-7*y-5]='0'+((f & 32)>0);
			frame[69-7*y-4]='0'+((f & 16)>0);
			frame[69-7*y-3]='0'+((f & 8)>0);
			frame[69-7*y-2]='0'+((f & 4)>0);
			frame[69-7*y-1]='0'+((f & 2)>0);
			frame[69-7*y-0]='0'+((f & 1)>0);
			y++;
		}

		/* decode */

		if (fail==0)
		{
			frame[70]=0;
			OP_code=((frame[0]-'0')<<5)+((frame[1]-'0')<<4)+((frame[2]-'0')<<3)+((frame[3]-'0')<<2)+((frame[4]-'0')<<1)+(frame[5]-'0');
			sprintf(datat,"%s",Funkdaten[OP_code]+64);
			c='-';
			x=0;
			y=0;
			ParNum=0;
			while(x<64)
			{
				if (c!=Funkdaten[OP_code][x])
				{
					ProcessPar(y,c);
					y=0;
					c=Funkdaten[OP_code][x];
				}
				y=(y<<1)+(frame[x+6]-'0');
				x++;
			}
			ProcessPar(y,c);
			sprintf(out,"\n");strcat(datat,out);
		}

		/* skip, if no einbuchdaten */

		if (MODE_ACT=='*')
		{
			if (fail)
			{
				goto failed;
			}
			if ((OP_code!=0) && (OP_code!=1) && (OP_code!=2) && (OP_code!=6) && (OP_code!=7))
			{
				goto failed;
			}
			if (func_value[0]==1)
			{
				goto failed;
			}
		}

		/* print line */

		RAW_TEXT;

		if (MODE_LIN=='*')
		{
			if ((MODE_ERR!='*') && (fail!=0))
				goto failed;
			sprintf(out,"----------------------------------------------------------------------------\n");print();
		}

		/* print time */

		if (MODE_TIM=='*')
		{
			if ((MODE_ERR!='*') && (fail!=0))
				goto failed;
			time(&t);
			tp=localtime(&t);
			sprintf(out,"Uhrzeit: %s",asctime(tp));print();
		}

		/* print error */

		if (MODE_ERR=='*')
 		{
			ACTION_TEXT;
			erro[10]=0;
			if (fail)
			{
				sprintf(out,"Fehler:'%s' (Daten ungltig)\n",erro);print();
			} else
			{
				if (warn)
				{
					sprintf(out,"Fehler:'%s' (Fehler korrigierbar)\n",erro);print();
				} else
				{
					sprintf(out,"Fehler:'%s' (keine Fehler)\n",erro);print();
				}
			}
		}

		if (fail)
		{
			goto failed;
		}
		/* print frame data */

		if (MODE_DAT=='*')
		{
			VAN_TEXT;
			sprintf(out,datat);print();
		}

		/* interpret */

		if (MODE_INT=='*')
		{
			INTER_TEXT;
			switch (OP_code)
			{
			  case 0:
				if (func_value[0])
				{
					sprintf(out,"<-Einbuchen (Chip)    0161-%d%d%05d in FuFSt %d,%d,%d.\n",func_value[8],func_value[9],func_value[10],func_value[5],func_value[6],func_value[7]);print();
					break;
			  	} else {
					sprintf(out,"<-Einbuchen (Magnet)  0161-%d%d%05d mit code: %d in FuFSt %d,%d,%d.\n",func_value[8],func_value[9],func_value[10],func_value[4],func_value[5],func_value[6],func_value[7]);print();
					break;
				}
			  case 1:
				if (func_value[0])
				{
					sprintf(out,"<-Umbuchen  (Chip)    0161-%d%d%05d in FuFSt %d,%d,%d.\n",func_value[8],func_value[9],func_value[10],func_value[5],func_value[6],func_value[7]);print();
					break;
			  	} else {
					sprintf(out,"<-Umbuchen  (Magnet)  0161-%d%d%05d mit code: %d in FuFSt %d,%d,%d.\n",func_value[8],func_value[9],func_value[10],func_value[4],func_value[5],func_value[6],func_value[7]);print();
					break;
				}
			  case 2:
				if (func_value[1])
				{
					sprintf(out,"<-UmbuchenWS(Chip)    0161-%d%d%05d in FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8]);print();
					break;
			  	} else {
					sprintf(out,"<-UmbuchenWS(Magnet)  0161-%d%d%05d mit code: %d in FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[5],func_value[6],func_value[7],func_value[8]);print();
					break;
				}
			  case 3:
				sprintf(out,"<-Auslsen von 0161-%d%d%05d an FuFSt %d,%d,%d. (Hersteller:%d,Hard:%d,Soft,%d)\n",func_value[8],func_value[9],func_value[10],func_value[5],func_value[6],func_value[7],func_value[2],func_value[3],func_value[4]);print();
				break;
			  case 4:
				sprintf(out,"<-Ruf von 0161-%d%d%05d an FuFSt %d,%d,%d. (Hersteller:%d,Hard:%d,Soft,%d)\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 5:
				sprintf(out,"<-SONDER-Ruf von      0161-%d%d%05d an FuFSt %d,%d,%d. (Hersteller:%d,Hard:%d,Soft,%d)\n",func_value[8],func_value[9],func_value[10],func_value[5],func_value[6],func_value[7],func_value[2],func_value[3],func_value[4]);print();
				break;
			  case 6:
				if (func_value[1])
				{
					sprintf(out,"<-Ruf (NUG) (Chip) von 0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8]);print();
					break;
			  	} else {
					sprintf(out,"<-Ruf (NUG) (Magnet) von 0161-%d%d%05d mit code: %d an FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[5],func_value[6],func_value[7],func_value[8]);print();
					break;
				}
			  case 7:
				if (func_value[0])
				{
					sprintf(out,"<-Umbuchungantrag (Chip) bei Warteschlange von 0161-%d%d%05d an FuFSt %d,%d,%d (gehend).\n",func_value[8],func_value[9],func_value[10],func_value[5],func_value[6],func_value[7]);print();
					break;
			  	} else {
					sprintf(out,"<-Umbuchungantrag (Magnet) bei Warteschlange von 0161-%d%d%05d mit code: %d an FuFSt %d,%d,%d (gehend).\n",func_value[8],func_value[9],func_value[10],func_value[4],func_value[5],func_value[6],func_value[7]);print();
					break;
				}
			  case 8:
				sprintf(out,"<-Meldung von         0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[3],func_value[4],func_value[5],func_value[0],func_value[1],func_value[2]);print();
				break;  
			  case 9:
			  case 11:
			  case 12:
			  case 13:
			  case 14:
			  case 15:
			  case 29:
			  case 30:
			  case 31:
			  case 34:
			  case 61:
			  case 62:
			  case 63:
				sprintf(out,"<-Illegales Telegram! (opcode=%d)\n",OP_code);print();
				break;  
			  case 10:
				sprintf(out,"<-Ruf nach %s.\n",func_result);print();
				break;
			  case 16:
				sprintf(out,"<-Belegung von        0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[5],func_value[6],func_value[7],func_value[2],func_value[3],func_value[4]);print();
				break;
			  case 17:
				sprintf(out,"<-Verbindung halten:  0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8]);print();
				break;
			  case 18:
				sprintf(out,"<-Quittung Rufton von 0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 19:
				sprintf(out,"<-Abheben von         0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[7],func_value[8],func_value[9],func_value[4],func_value[5],func_value[6]);print();
				break;
			  case 20:
				sprintf(out,"<-Verbindung halten:  0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 21:
				sprintf(out,"<-Auslsen von        0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[5],func_value[6],func_value[7],func_value[2],func_value[3],func_value[4]);print();
				break;
			  case 22:
				sprintf(out,"<-Auslsen von        0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[7],func_value[8],func_value[9],func_value[4],func_value[5],func_value[6]);print();
				break;
			  case 23:
				sprintf(out,"<-Durchschaltquittung:0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[7],func_value[8],func_value[9],func_value[4],func_value[5],func_value[6]);print();
				break;
			  case 24:
				sprintf(out,"<-Internes d-schalten:0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8]);print();
				break;
			  case 25:
				sprintf(out,"<-Internes d-schalten:0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[9],func_value[10],func_value[11],func_value[6],func_value[7],func_value[8]);print();
				break;
			  case 26:
				sprintf(out,"<-Umschalten von      0161-%d%d%05d an FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 27:
				sprintf(out,"<-Zufallszahl            :%%%s.\n",frame);print();
				break;
			  case 28:
				sprintf(out,"<-Autorisierungsparameter:%%%s.\n",frame);print();
				break;
			  case 32:
				ParNum=4;
				Func_K();
				sprintf(out,"->Meldeaufruf an      0161-%d%d%05d von FuFSt ?,%d,%d mit OgK-Vorschlag bei der Frequenz %s.\n",func_value[6],func_value[7],func_value[8],func_value[4],func_value[5],func_result);print();
				break;
			  case 33:
				sprintf(out,"->Anruf fr 0161-%d%d%05d auf Frequenz %s der FuFSt %d,%d,%d.\n",func_value[7],func_value[8],func_value[9],func_result,func_value[4],func_value[5],func_value[6]);print();
				ParNum=3;
				Func_K();
				break;
			  case 46:
				ParNum=3;
				Func_K();
				sprintf(out,"->Teilnehmer 0161-%d%d%05d ruft auf Frequenz %s FuFSt %d,%d,%d.\n",func_value[7],func_value[8],func_value[9],func_result,func_value[4],func_value[5],func_value[6]);print();
				break;
/*bis hier*/		  case 47:
			  case 48:
			  case 49:
			  case 50:
			  case 51:
			  case 52:
			  case 53:
			  case 54:
			  case 55:
			  case 56:
			  case 57:
			  case 58:
			  case 59:
			  case 60:
				sprintf(out,"*** Nicht implementiert! (opcode=%d)\n",OP_code);print();
				break;
			  case 35:
				sprintf(out,"->Einbuchquittierung  0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 36:
				sprintf(out,"->Einbuchquittierung  0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 37:
				sprintf(out,"->Umbuchquittierung   0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 38:
				ParNum=4;
				Func_K();
				sprintf(out,"->Melde Leerruf von FuFSt ?,?,%d mit OgK-Vorschlag bei der Frequenz %s\n",func_value[5],func_result);print();
				break;
			  case 39:
				sprintf(out,"->Leerruf der FuFSt %d,%d,%d",func_value[8],func_value[9],func_value[10]);print();
				if (func_value[4])
				{
					sprintf(out," mit Authentification.\n");print();
				} else {
					sprintf(out," ohne Authentification.\n");print();
				}
				break;
			  case 41:
				sprintf(out,"->Sperraufruf an 0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 42:
				sprintf(out,"->Wahlaufforderung an 0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 43:
				sprintf(out,"->Wahlbesttigung positiv an 0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 44:
				sprintf(out,"->Wahlbesttigung negativ an 0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			  case 45:
				sprintf(out,"->Wahlbesttigung positiv (WS) an 0161-%d%d%05d der FuFSt %d,%d,%d.\n",func_value[6],func_value[7],func_value[8],func_value[3],func_value[4],func_value[5]);print();
				break;
			}
		}

#ifdef SAMPLER
		if (MODE_OUT=='*')
		{
			Delay(50);
		}
#endif
		failed:
		dummy();
	}
	rring=(rring+1)&63;
#ifdef SAMPLER
	if (buf==0) /* buf is 0, if scan() routine was interrupted by left mouse button */
		brk=TRUE;
#endif
} 

void CloseAll( void )
{
#ifndef SAMPLER
	T_Stop(TSF_DONTSAVECACHE);
#endif
	WARN_TEXT;
#ifndef SAMPLER
	printf("Toccata stopt\n");
	if (ToccataBase) CloseLibrary((struct Library *)ToccataBase);
#endif
	RAW_TEXT;
}


int Break( void )
{
	brk=TRUE;
	return(0);
}

int main( void )
{
/*	UBYTE *bfe001 = (UBYTE *)0xbfe001;
*/	FILE *fp;
	char c;

	printf("NEUROSCAN V1.3 / kick da C-Netz\n\n");

	if (fp=fopen("envarc:biene.prefs","r"))
	{
		MODE_LIN=fgetc(fp);
		MODE_TIM=fgetc(fp);
		MODE_ERR=fgetc(fp);
		MODE_DAT=fgetc(fp);
		MODE_INT=fgetc(fp);
		MODE_ACT=fgetc(fp);
		MODE_CAP=fgetc(fp);
		MODE_OUT=fgetc(fp);
		fread(Capture,256,1,fp);
		fclose(fp);
	} else
	{
		WARN_TEXT;
		printf("* Kann Einstellungen nicht finden\n");
	}

	if (onbreak(&Break))
	{
		WARN_TEXT;
		printf("* Interner fehler: Break-Trap kann nicht gesetzt werden\n");
		CloseAll();
		return(20L);
	}
#ifndef SAMPLER
	if (!(ToccataBase = (struct ToccataBase *)OpenLibrary("toccata.library",0L)))
	{
		WARN_TEXT;
		puts("* Interner fehler: Wo ist die toccata.library?");
		CloseAll();
		return(20L);
	}

	wring=rring=0;
	T_SetPart((struct TagItem *)TocPat);
	T_Capture((struct TagItem *)TocTags);	
	WARN_TEXT;
	printf("Drcke CTRL+C fr men.\n<Toccata luft>\n");
#endif
#ifdef SAMPLER
	WARN_TEXT;
	printf("Drcke linke Maustaste fr men.\n<benutze sampler eingang (68000/chip only)>\n");
#endif

	while (/* *bfe001 & 0x40 */ 1)
	{
		if (brk==TRUE)
		{
			brk=FALSE;
			RAW_TEXT;
#ifndef SAMPLER
			T_Stop(TSF_DONTSAVECACHE);
#endif
			
			menu:
			printf("    \n");
			printf("%c (0) Schalter Linie\n",MODE_LIN);
			printf("%c (1) Schalter Uhrzeit+Datum\n",MODE_TIM);
			printf("%c (2) Schalter Fehlerliste\n",MODE_ERR);
			printf("%c (3) Schalter Daten\n",MODE_DAT);
			printf("%c (4) Schalter Zusammenfassung\n",MODE_INT);
			printf("%c (5) Nur Einbuchdaten (Magnet) anzeigen\n",MODE_ACT);
			printf("%c (c) Schalter Mitschneiden: %s\n",MODE_CAP,Capture);
			printf("%c (d) Schalter Ausgabe (stdout)\n",MODE_OUT);
			printf("  (s) Einstellungen speichern\n");
			printf("  (q) Programm verlassen\n");
			printf("Weiter mit Space\n");
			printf("\n->");
			getkey:
			c=getch();
			switch (c)
			{
			  case '0':
				MODE_LIN=(MODE_LIN==' ')?'*':' ';
				goto menu;
			  case '1':
				MODE_TIM=(MODE_TIM==' ')?'*':' ';
				goto menu;
			  case '2':
				MODE_ERR=(MODE_ERR==' ')?'*':' ';
				goto menu;
			  case '3':
				MODE_DAT=(MODE_DAT==' ')?'*':' ';
				goto menu;
			  case '4':
				MODE_INT=(MODE_INT==' ')?'*':' ';
				goto menu;
			  case '5':
				MODE_ACT=(MODE_ACT==' ')?'*':' ';
				goto menu;
			  case 'c':
				MODE_CAP=(MODE_CAP==' ')?'*':' ';
				if (MODE_CAP=='*')
				{
					printf("\nDateiname:");
					scanf("%s",Capture);
					printf("\n");
				}
				goto menu;
			  case 'd':
				MODE_OUT=(MODE_OUT==' ')?'*':' ';
				goto menu;
			  case 's':
				if (fp=fopen("envarc:biene.prefs","w"))
				{
					fputc(MODE_LIN,fp);
					fputc(MODE_TIM,fp);
					fputc(MODE_ERR,fp);
					fputc(MODE_DAT,fp);
					fputc(MODE_INT,fp);
					fputc(MODE_ACT,fp);
					fputc(MODE_CAP,fp);
					fputc(MODE_OUT,fp);
					fwrite(Capture,256,1,fp);
					fclose(fp);
				} else
				{
					WARN_TEXT;
					printf("* Fehler beim schreiben der Einstellungen nach envarc:biene.prefs\n");
				}
				break;
			  case 'q':
				printf("\n\n");
				CloseAll();
				return(0);
				break;
			}
			if (c!=32)
			{
				goto getkey;
			}
			printf("\n\n");
#ifndef SAMPLER
			T_Capture((struct TagItem *)TocTags);	
			rring=wring;
#endif
		}
		/*printf("Hinker:%d\n",(wring-rring)&63);*/
#ifdef SAMPLER
		ProcessSample();
#endif
#ifndef SAMPLER
		if (wring!=rring)
		{
			ProcessSample();
			if (((wring-rring)&63)>31)
			{
				WARN_TEXT;
				puts("**** Die Daten knnen nicht schnell genug analysiert werden!");
				rring=wring;
			}
		} else
		{
			WARN_TEXT;
			printf("%s\r",waitpoint[(rring/4)&3]);
			oring=wring;
			Delay(30);
			if (oring==wring)
			{
				T_Stop(TSF_DONTSAVECACHE);
				WARN_TEXT;
				printf("<Toccata neustart>\n");
				T_Capture((struct TagItem *)TocTags);	
			}
			fflush(stdout);
		}
#endif
	}
	CloseAll();
	return(0L);
}

#ifndef SAMPLER
BOOL CB_Save(UBYTE *Data, ULONG Size)
{
	CopyMem(Data,buf+(wring*BUFSIZE),Size);
	wring=(wring+1)&63;
	return(TRUE);
}
#endif
