; * decoder for FSK modulation supplied on a sampler of a 68000 with chip mem

;*****************************************************************************

;format of table:

;input: 000lbbbssdddddi0
;output:00000lbbbssddddd

;l=last state of signal
;b=bitcounter (1/8 of one bit = samples 0-7)
;s=sync state	00=wait first sync word			(0010010111)
;		01=first sync found, wait for second	(0001001011)
;		10=second sync found, wait for third	(1000100101)
;		11=third sync read, read data packet
;d=data-shift-register
;		if sync state is 0-2, the register shows the current bit
;		read (0-9)
;		if sync state is 3, the register shows the bits read,
;		shifting in from the right to the left
;		the most left bit will show a 1, to give a length of the
;		register. if all 4 bits are read, the first bit show the 1
;		and the register is ready to be written.
;i=incoming signal

;*****************************************************************************
;	bra convert

XDEF	_SCAN

_SCAN:
		move.l	$4,a6
		jsr	-$78(a6)

		move.w	#%0000001000000000,$dff096

		bsr	scan

		move.w	#%1000001000000000,$dff096

		move.l	$4,a6
		jsr	-$7e(a6)
		move.l	return,d0
		rts


;*****************************************************************************

test:		move.l	#scantab,a0		;base address to scantab
		move.l	#rawtab,a1		;base of 38 byte raw table
		moveq	#0,d0			;reset interation status

		move.w	#60-1,d4
floop:		move.w	#6*10-1,d3
		move.w	#529-1,d1		;(37.5*4bit=150bit)
tloop:		bra	scanloop
texit:		dbf	d3,tloop
		dbf	d4,floop
		rts

;*****************************************************************************

scan:		move.w	#38,d1			;(37.5*4bit=150bit)
		move.l	#scantab,a0		;base address to scantab
		move.l	#rawtab,a1		;base of 38 byte raw table
		moveq	#0,d0			;reset interation status
		or.b	#%00000110,$bfd200
		and.b	#%11111001,$bfd000
		or.b	#%00000010,$bfd000	;left sampler
		;or.b	#%00000011,$bfd000	;right sampler
		move.b	#%10000000,d5		;sign

;	move.l #$1f0000,a2

		;read until data found or mouse click

scanloop1:	subq	#1,d2			;dummy wait
		bra	scanloop
scanloop:	btst	#6,$bfe001
		beq	scanint
		lsl.l	#8,d0			;make space
		move.b	$bfe101,d0		;insert bit 7
		eor.b	d5,d0			;adjust sign
;	move.b (a2)+,d0
		lsr.l	#6,d0			;shift down
		and.w	#%0001111111111110,d0	;erase bits
		move.w	(a0,d0.w),d0		;lookup table (15 bit only=no sign)
		move.w	d0,$dff180
		move.b	d0,(a1,d1.w)		;write byte
		btst	#15,d0			;check test-exit
		bne	texit
		btst	#4,d0			;check if write flag is set
		beq	scanloop1
		subq	#1,d1
		bne	scanloop
;		rts

		;convert to 10 words

convert:	move.l	#vantab,a0		;base of 10 words table (20 bytes)
		move.b	#'1',(a0)+
		move.l	#rawtab,a1		;base of 38 byte raw table
		moveq	#0,d0			;counter for vanilla data
		move.w	#4,d2			;bit counter for raw nibble
		move.w	#38,d3			;byte counter for raw nibbles

bitloop:	cmp.w	#4,d2
		bne	nonibble
		move.b	(a1,d3.w),d4		;read nibble
		subq	#1,d3
		moveq	#0,d2
nonibble:	addq	#1,d2

		move.b	#'0',d1
		btst	#3,d4			;check msb
		beq	nobitset
		move.b	#'1',d1
nobitset:	move.b	d1,(a0)+
		lsl.b	#1,d4

		addq	#1,d0
		cmp.w	#150,d0
		bne	bitloop

		move.l	#vantab,return		;vantab with resulting data
		rts

scanint:	move.l	#0,return		;false (break by mouse)
		rts

;*****************************************************************************

return:		dc.l	0

;testogk:	blk.b 1500
>extern"data:test.ogk",$1f0000,1500

;scantab:
;test table
dc.w 1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8
dc.w 9,9,10,10,11,11,12,12,13,13,14,14,15,15,32,32
dc.w 1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8
dc.w 9,9,10,10,11,11,12,12,13,13,14,14,15,15,32,32
dc.w 33,33,34,34,35,35,36,36,37,37,38,38,39,39,40,40
dc.w 41,41,42,42,43,43,44,44,45,45,46,46,47,47,64,64
dc.w 33,33,34,34,35,35,36,36,37,37,38,38,39,39,40,40
dc.w 41,41,42,42,43,43,44,44,45,45,46,46,47,47,64,64
dc.w 65,65,66,66,67,67,68,68,69,69,70,70,71,71,72,72
dc.w 73,73,74,74,75,75,76,76,77,77,78,78,79,79,96,96
dc.w 65,65,66,66,67,67,68,68,69,69,70,70,71,71,72,72
dc.w 73,73,74,74,75,75,76,76,77,77,78,78,79,79,96,96
dc.w 97,97,98,98,99,99,100,100,101,101,102,102,103,103,104,104
dc.w 105,105,106,106,107,107,108,108,109,109,110,110,111,111,128,128
dc.w 97,97,98,98,99,99,100,100,101,101,102,102,103,103,104,104
dc.w 105,105,106,106,107,107,108,108,109,109,110,110,111,111,128,128
dc.w 129,129,130,130,131,131,132,132,133,133,134,134,135,135,136,136
dc.w 137,137,138,138,139,139,140,140,141,141,142,142,143,143,160,160
dc.w 129,129,130,130,131,131,132,132,133,133,134,134,135,135,136,136
dc.w 137,137,138,138,139,139,140,140,141,141,142,142,143,143,160,160
dc.w 161,161,162,162,163,163,164,164,165,165,166,166,167,167,168,168
dc.w 169,169,170,170,171,171,172,172,173,173,174,174,175,175,192,192
dc.w 161,161,162,162,163,163,164,164,165,165,166,166,167,167,168,168
dc.w 169,169,170,170,171,171,172,172,173,173,174,174,175,175,192,192
dc.w 193,193,194,194,195,195,196,196,197,197,198,198,199,199,200,200
dc.w 201,201,202,202,203,203,204,204,205,205,206,206,207,207,224,224
dc.w 193,193,194,194,195,195,196,196,197,197,198,198,199,199,200,200
dc.w 201,201,202,202,203,203,204,204,205,205,206,206,207,207,224,224
dc.w 225,225,226,226,227,227,228,228,229,229,230,230,231,231,232,232
dc.w 233,233,234,234,235,235,236,236,237,237,238,238,239,239,256,256
dc.w 225,225,226,226,227,227,228,228,229,229,230,230,231,231,232,232
dc.w 233,233,234,234,235,235,236,236,237,237,238,238,239,239,256,256
dc.w 257,257,258,258,259,259,260,260,261,261,262,262,263,263,264,264
dc.w 265,265,266,266,267,267,268,268,269,269,270,270,271,271,288,288
dc.w 257,257,258,258,259,259,260,260,261,261,262,262,263,263,264,264
dc.w 265,265,266,266,267,267,268,268,269,269,270,270,271,271,288,288
dc.w 289,289,290,290,291,291,292,292,293,293,294,294,295,295,296,296
dc.w 297,297,298,298,299,299,300,300,301,301,302,302,303,303,320,320
dc.w 289,289,290,290,291,291,292,292,293,293,294,294,295,295,296,296
dc.w 297,297,298,298,299,299,300,300,301,301,302,302,303,303,320,320
dc.w 321,321,322,322,323,323,324,324,325,325,326,326,327,327,328,328
dc.w 329,329,330,330,331,331,332,332,333,333,334,334,335,335,352,352
dc.w 321,321,322,322,323,323,324,324,325,325,326,326,327,327,328,328
dc.w 329,329,330,330,331,331,332,332,333,333,334,334,335,335,352,352
dc.w 353,353,354,354,355,355,356,356,357,357,358,358,359,359,360,360
dc.w 361,361,362,362,363,363,364,364,365,365,366,366,367,367,384,384
dc.w 353,353,354,354,355,355,356,356,357,357,358,358,359,359,360,360
dc.w 361,361,362,362,363,363,364,364,365,365,366,366,367,367,384,384
dc.w 385,385,386,386,387,387,388,388,389,389,390,390,391,391,392,392
dc.w 393,393,394,394,395,395,396,396,397,397,398,398,399,399,416,416
dc.w 385,385,386,386,387,387,388,388,389,389,390,390,391,391,392,392
dc.w 393,393,394,394,395,395,396,396,397,397,398,398,399,399,416,416
dc.w 417,417,418,418,419,419,420,420,421,421,422,422,423,423,424,424
dc.w 425,425,426,426,427,427,428,428,429,429,430,430,431,431,448,448
dc.w 417,417,418,418,419,419,420,420,421,421,422,422,423,423,424,424
dc.w 425,425,426,426,427,427,428,428,429,429,430,430,431,431,448,448
dc.w 449,449,450,450,451,451,452,452,453,453,454,454,455,455,456,456
dc.w 457,457,458,458,459,459,460,460,461,461,462,462,463,463,480,480
dc.w 449,449,450,450,451,451,452,452,453,453,454,454,455,455,456,456
dc.w 457,457,458,458,459,459,460,460,461,461,462,462,463,463,480,480
dc.w 481,481,482,482,483,483,484,484,485,485,486,486,487,487,488,488
dc.w 489,489,490,490,491,491,492,492,493,493,494,494,495,495,512,512
dc.w 481,481,482,482,483,483,484,484,485,485,486,486,487,487,488,488
dc.w 489,489,490,490,491,491,492,492,493,493,494,494,495,495,512,512
dc.w 513,513,514,514,515,515,516,516,517,517,518,518,519,519,520,520
dc.w 521,521,522,522,523,523,524,524,525,525,526,526,527,527,544,544
dc.w 513,513,514,514,515,515,516,516,517,517,518,518,519,519,520,520
dc.w 521,521,522,522,523,523,524,524,525,525,526,526,527,527,544,544
dc.w 545,545,546,546,547,547,548,548,549,549,550,550,551,551,552,552
dc.w 553,553,554,554,555,555,556,556,557,557,558,558,559,559,576,576
dc.w 545,545,546,546,547,547,548,548,549,549,550,550,551,551,552,552
dc.w 553,553,554,554,555,555,556,556,557,557,558,558,559,559,576,576
dc.w 577,577,578,578,579,579,580,580,581,581,582,582,583,583,584,584
dc.w 585,585,586,586,587,587,588,588,589,589,590,590,591,591,608,608
dc.w 577,577,578,578,579,579,580,580,581,581,582,582,583,583,584,584
dc.w 585,585,586,586,587,587,588,588,589,589,590,590,591,591,608,608
dc.w 609,609,610,610,611,611,612,612,613,613,614,614,615,615,616,616
dc.w 617,617,618,618,619,619,620,620,621,621,622,622,623,623,640,640
dc.w 609,609,610,610,611,611,612,612,613,613,614,614,615,615,616,616
dc.w 617,617,618,618,619,619,620,620,621,621,622,622,623,623,640,640
dc.w 641,641,642,642,643,643,644,644,645,645,646,646,647,647,648,648
dc.w 649,649,650,650,651,651,652,652,653,653,654,654,655,655,672,672
dc.w 641,641,642,642,643,643,644,644,645,645,646,646,647,647,648,648
dc.w 649,649,650,650,651,651,652,652,653,653,654,654,655,655,672,672
dc.w 673,673,674,674,675,675,676,676,677,677,678,678,679,679,680,680
dc.w 681,681,682,682,683,683,684,684,685,685,686,686,687,687,704,704
dc.w 673,673,674,674,675,675,676,676,677,677,678,678,679,679,680,680
dc.w 681,681,682,682,683,683,684,684,685,685,686,686,687,687,704,704
dc.w 705,705,706,706,707,707,708,708,709,709,710,710,711,711,712,712
dc.w 713,713,714,714,715,715,716,716,717,717,718,718,719,719,736,736
dc.w 705,705,706,706,707,707,708,708,709,709,710,710,711,711,712,712
dc.w 713,713,714,714,715,715,716,716,717,717,718,718,719,719,736,736
dc.w 737,737,738,738,739,739,740,740,741,741,742,742,743,743,744,744
dc.w 745,745,746,746,747,747,748,748,749,749,750,750,751,751,768,768
dc.w 737,737,738,738,739,739,740,740,741,741,742,742,743,743,744,744
dc.w 745,745,746,746,747,747,748,748,749,749,750,750,751,751,768,768
dc.w 769,769,770,770,771,771,772,772,773,773,774,774,775,775,776,776
dc.w 777,777,778,778,779,779,780,780,781,781,782,782,783,783,800,800
dc.w 769,769,770,770,771,771,772,772,773,773,774,774,775,775,776,776
dc.w 777,777,778,778,779,779,780,780,781,781,782,782,783,783,800,800
dc.w 801,801,802,802,803,803,804,804,805,805,806,806,807,807,808,808
dc.w 809,809,810,810,811,811,812,812,813,813,814,814,815,815,832,832
dc.w 801,801,802,802,803,803,804,804,805,805,806,806,807,807,808,808
dc.w 809,809,810,810,811,811,812,812,813,813,814,814,815,815,832,832
dc.w 833,833,834,834,835,835,836,836,837,837,838,838,839,839,840,840
dc.w 841,841,842,842,843,843,844,844,845,845,846,846,847,847,864,864
dc.w 833,833,834,834,835,835,836,836,837,837,838,838,839,839,840,840
dc.w 841,841,842,842,843,843,844,844,845,845,846,846,847,847,864,864
dc.w 865,865,866,866,867,867,868,868,869,869,870,870,871,871,872,872
dc.w 873,873,874,874,875,875,876,876,877,877,878,878,879,879,896,896
dc.w 865,865,866,866,867,867,868,868,869,869,870,870,871,871,872,872
dc.w 873,873,874,874,875,875,876,876,877,877,878,878,879,879,896,896
dc.w 897,897,898,898,899,899,900,900,901,901,902,902,903,903,904,904
dc.w 905,905,906,906,907,907,908,908,909,909,910,910,911,911,928,928
dc.w 897,897,898,898,899,899,900,900,901,901,902,902,903,903,904,904
dc.w 905,905,906,906,907,907,908,908,909,909,910,910,911,911,928,928
dc.w 929,929,930,930,931,931,932,932,933,933,934,934,935,935,936,936
dc.w 937,937,938,938,939,939,940,940,941,941,942,942,943,943,960,960
dc.w 929,929,930,930,931,931,932,932,933,933,934,934,935,935,936,936
dc.w 937,937,938,938,939,939,940,940,941,941,942,942,943,943,960,960
dc.w 961,961,962,962,963,963,964,964,965,965,966,966,967,967,968,968
dc.w 969,969,970,970,971,971,972,972,973,973,974,974,975,975,992,992
dc.w 961,961,962,962,963,963,964,964,965,965,966,966,967,967,968,968
dc.w 969,969,970,970,971,971,972,972,973,973,974,974,975,975,992,992
dc.w 993,993,994,994,995,995,996,996,997,997,998,998,999,999,1000,1000
dc.w 1001,1001,1002,1002,1003,1003,1004,1004,1005,1005,1006,1006,1007,1007,1024,1024
dc.w 993,993,994,994,995,995,996,996,997,997,998,998,999,999,1000,1000
dc.w 1001,1001,1002,1002,1003,1003,1004,1004,1005,1005,1006,1006,1007,1007,1024,1024
dc.w 1025,1025,1026,1026,1027,1027,1028,1028,1029,1029,1030,1030,1031,1031,1032,1032
dc.w 1033,1033,1034,1034,1035,1035,1036,1036,1037,1037,1038,1038,1039,1039,1056,1056
dc.w 1025,1025,1026,1026,1027,1027,1028,1028,1029,1029,1030,1030,1031,1031,1032,1032
dc.w 1033,1033,1034,1034,1035,1035,1036,1036,1037,1037,1038,1038,1039,1039,1056,1056
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768
dc.w 32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768,32768


scantab:
;scan table
dc.w 128,1026,129,1026,130,1024,131,1028,132,1029,133,1024,134,1031,135,1024
dc.w 136,1024,137,1024,138,1034,139,1035,140,1036,141,1037,142,1038,143,1039
dc.w 144,1040,145,1041,146,1042,147,1043,148,1044,149,1045,150,1046,151,1047
dc.w 152,1048,153,1049,154,1050,155,1051,156,1052,157,1053,158,1054,159,1055
dc.w 160,1056,161,1057,162,1058,163,1059,164,1060,165,1061,166,1062,167,1063
dc.w 168,1064,169,1065,170,1066,171,1067,172,1068,173,1069,174,1070,175,1071
dc.w 176,1072,177,1073,178,1074,179,1075,180,1076,181,1077,182,1078,183,1079
dc.w 184,1080,185,1081,186,1082,187,1083,188,1084,189,1085,190,1086,191,1087
dc.w 192,1088,193,1089,194,1090,195,1091,196,1092,197,1093,198,1094,199,1095
dc.w 200,1096,201,1097,202,1098,203,1099,204,1100,205,1101,206,1102,207,1103
dc.w 208,1104,209,1105,210,1106,211,1107,212,1108,213,1109,214,1110,215,1111
dc.w 216,1112,217,1113,218,1114,219,1115,220,1116,221,1117,222,1118,223,1119
dc.w 224,1120,225,1121,226,1122,227,1123,228,1124,229,1125,230,1126,231,1127
dc.w 232,1128,233,1129,234,1130,235,1131,236,1132,237,1133,238,1134,239,1135
dc.w 225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121
dc.w 225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121
dc.w 256,1026,257,1026,258,1024,259,1028,260,1029,261,1024,262,1031,263,1024
dc.w 264,1024,265,1024,266,1034,267,1035,268,1036,269,1037,270,1038,271,1039
dc.w 272,1040,273,1041,274,1042,275,1043,276,1044,277,1045,278,1046,279,1047
dc.w 280,1048,281,1049,282,1050,283,1051,284,1052,285,1053,286,1054,287,1055
dc.w 288,1056,289,1057,290,1058,291,1059,292,1060,293,1061,294,1062,295,1063
dc.w 296,1064,297,1065,298,1066,299,1067,300,1068,301,1069,302,1070,303,1071
dc.w 304,1072,305,1073,306,1074,307,1075,308,1076,309,1077,310,1078,311,1079
dc.w 312,1080,313,1081,314,1082,315,1083,316,1084,317,1085,318,1086,319,1087
dc.w 320,1088,321,1089,322,1090,323,1091,324,1092,325,1093,326,1094,327,1095
dc.w 328,1096,329,1097,330,1098,331,1099,332,1100,333,1101,334,1102,335,1103
dc.w 336,1104,337,1105,338,1106,339,1107,340,1108,341,1109,342,1110,343,1111
dc.w 344,1112,345,1113,346,1114,347,1115,348,1116,349,1117,350,1118,351,1119
dc.w 352,1120,353,1121,354,1122,355,1123,356,1124,357,1125,358,1126,359,1127
dc.w 360,1128,361,1129,362,1130,363,1131,364,1132,365,1133,366,1134,367,1135
dc.w 353,1121,353,1121,353,1121,353,1121,353,1121,353,1121,353,1121,353,1121
dc.w 353,1121,353,1121,353,1121,353,1121,353,1121,353,1121,353,1121,353,1121
dc.w 384,1026,385,1026,386,1024,387,1028,388,1029,389,1024,390,1031,391,1024
dc.w 392,1024,393,1024,394,1034,395,1035,396,1036,397,1037,398,1038,399,1039
dc.w 400,1040,401,1041,402,1042,403,1043,404,1044,405,1045,406,1046,407,1047
dc.w 408,1048,409,1049,410,1050,411,1051,412,1052,413,1053,414,1054,415,1055
dc.w 416,1056,417,1057,418,1058,419,1059,420,1060,421,1061,422,1062,423,1063
dc.w 424,1064,425,1065,426,1066,427,1067,428,1068,429,1069,430,1070,431,1071
dc.w 432,1072,433,1073,434,1074,435,1075,436,1076,437,1077,438,1078,439,1079
dc.w 440,1080,441,1081,442,1082,443,1083,444,1084,445,1085,446,1086,447,1087
dc.w 448,1088,449,1089,450,1090,451,1091,452,1092,453,1093,454,1094,455,1095
dc.w 456,1096,457,1097,458,1098,459,1099,460,1100,461,1101,462,1102,463,1103
dc.w 464,1104,465,1105,466,1106,467,1107,468,1108,469,1109,470,1110,471,1111
dc.w 472,1112,473,1113,474,1114,475,1115,476,1116,477,1117,478,1118,479,1119
dc.w 480,1120,481,1121,482,1122,483,1123,484,1124,485,1125,486,1126,487,1127
dc.w 488,1128,489,1129,490,1130,491,1131,492,1132,493,1133,494,1134,495,1135
dc.w 481,1121,481,1121,481,1121,481,1121,481,1121,481,1121,481,1121,481,1121
dc.w 481,1121,481,1121,481,1121,481,1121,481,1121,481,1121,481,1121,481,1121
dc.w 512,1026,513,1026,514,1024,515,1028,516,1029,517,1024,518,1031,519,1024
dc.w 520,1024,521,1024,522,1034,523,1035,524,1036,525,1037,526,1038,527,1039
dc.w 528,1040,529,1041,530,1042,531,1043,532,1044,533,1045,534,1046,535,1047
dc.w 536,1048,537,1049,538,1050,539,1051,540,1052,541,1053,542,1054,543,1055
dc.w 544,1057,545,1058,546,1059,547,1024,548,1061,549,1062,550,1024,551,1064
dc.w 552,1024,553,1024,554,1066,555,1067,556,1068,557,1069,558,1070,559,1071
dc.w 560,1072,561,1073,562,1074,563,1075,564,1076,565,1077,566,1078,567,1079
dc.w 568,1080,569,1081,570,1082,571,1083,572,1084,573,1085,574,1086,575,1087
dc.w 576,1024,577,1090,578,1091,579,1092,580,1024,581,1094,582,1095,583,1024
dc.w 584,1097,585,1024,586,1098,587,1099,588,1100,589,1101,590,1102,591,1103
dc.w 592,1104,593,1105,594,1106,595,1107,596,1108,597,1109,598,1110,599,1111
dc.w 600,1112,601,1113,602,1114,603,1115,604,1116,605,1117,606,1118,607,1119
dc.w 608,1122,609,1122,610,1124,611,1126,612,1128,613,1130,614,1132,615,1134
dc.w 616,1136,617,1138,618,1140,619,1142,620,1144,621,1146,622,1148,623,1150
dc.w 609,1122,609,1122,609,1122,609,1122,609,1122,609,1122,609,1122,609,1122
dc.w 609,1122,609,1122,609,1122,609,1122,609,1122,609,1122,609,1122,609,1122
dc.w 640,1026,641,1026,642,1024,643,1028,644,1029,645,1024,646,1031,647,1024
dc.w 648,1024,649,1024,650,1034,651,1035,652,1036,653,1037,654,1038,655,1039
dc.w 656,1040,657,1041,658,1042,659,1043,660,1044,661,1045,662,1046,663,1047
dc.w 664,1048,665,1049,666,1050,667,1051,668,1052,669,1053,670,1054,671,1055
dc.w 672,1057,673,1058,674,1059,675,1024,676,1061,677,1062,678,1024,679,1064
dc.w 680,1024,681,1024,682,1066,683,1067,684,1068,685,1069,686,1070,687,1071
dc.w 688,1072,689,1073,690,1074,691,1075,692,1076,693,1077,694,1078,695,1079
dc.w 696,1080,697,1081,698,1082,699,1083,700,1084,701,1085,702,1086,703,1087
dc.w 704,1024,705,1090,706,1091,707,1092,708,1024,709,1094,710,1095,711,1024
dc.w 712,1097,713,1024,714,1098,715,1099,716,1100,717,1101,718,1102,719,1103
dc.w 720,1104,721,1105,722,1106,723,1107,724,1108,725,1109,726,1110,727,1111
dc.w 728,1112,729,1113,730,1114,731,1115,732,1116,733,1117,734,1118,735,1119
dc.w 736,1122,737,1122,738,1124,739,1126,740,1128,741,1130,742,1132,743,1134
dc.w 744,1136,745,1138,746,1140,747,1142,748,1144,749,1146,750,1148,751,1150
dc.w 737,1122,737,1122,737,1122,737,1122,737,1122,737,1122,737,1122,737,1122
dc.w 737,1122,737,1122,737,1122,737,1122,737,1122,737,1122,737,1122,737,1122
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 0,1152,0,1153,3,1154,0,1155,0,1156,6,1157,0,1158,8,1159
dc.w 9,1160,32,1161,10,1162,11,1163,12,1164,13,1165,14,1166,15,1167
dc.w 16,1168,17,1169,18,1170,19,1171,20,1172,21,1173,22,1174,23,1175
dc.w 24,1176,25,1177,26,1178,27,1179,28,1180,29,1181,30,1182,31,1183
dc.w 32,1184,33,1185,34,1186,35,1187,36,1188,37,1189,38,1190,39,1191
dc.w 40,1192,41,1193,42,1194,43,1195,44,1196,45,1197,46,1198,47,1199
dc.w 48,1200,49,1201,50,1202,51,1203,52,1204,53,1205,54,1206,55,1207
dc.w 56,1208,57,1209,58,1210,59,1211,60,1212,61,1213,62,1214,63,1215
dc.w 64,1216,65,1217,66,1218,67,1219,68,1220,69,1221,70,1222,71,1223
dc.w 72,1224,73,1225,74,1226,75,1227,76,1228,77,1229,78,1230,79,1231
dc.w 80,1232,81,1233,82,1234,83,1235,84,1236,85,1237,86,1238,87,1239
dc.w 88,1240,89,1241,90,1242,91,1243,92,1244,93,1245,94,1246,95,1247
dc.w 96,1248,97,1249,98,1250,99,1251,100,1252,101,1253,102,1254,103,1255
dc.w 104,1256,105,1257,106,1258,107,1259,108,1260,109,1261,110,1262,111,1263
dc.w 97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249
dc.w 97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249
dc.w 0,1280,0,1281,3,1282,0,1283,0,1284,6,1285,0,1286,8,1287
dc.w 9,1288,32,1289,10,1290,11,1291,12,1292,13,1293,14,1294,15,1295
dc.w 16,1296,17,1297,18,1298,19,1299,20,1300,21,1301,22,1302,23,1303
dc.w 24,1304,25,1305,26,1306,27,1307,28,1308,29,1309,30,1310,31,1311
dc.w 32,1312,33,1313,34,1314,35,1315,36,1316,37,1317,38,1318,39,1319
dc.w 40,1320,41,1321,42,1322,43,1323,44,1324,45,1325,46,1326,47,1327
dc.w 48,1328,49,1329,50,1330,51,1331,52,1332,53,1333,54,1334,55,1335
dc.w 56,1336,57,1337,58,1338,59,1339,60,1340,61,1341,62,1342,63,1343
dc.w 64,1344,65,1345,66,1346,67,1347,68,1348,69,1349,70,1350,71,1351
dc.w 72,1352,73,1353,74,1354,75,1355,76,1356,77,1357,78,1358,79,1359
dc.w 80,1360,81,1361,82,1362,83,1363,84,1364,85,1365,86,1366,87,1367
dc.w 88,1368,89,1369,90,1370,91,1371,92,1372,93,1373,94,1374,95,1375
dc.w 96,1376,97,1377,98,1378,99,1379,100,1380,101,1381,102,1382,103,1383
dc.w 104,1384,105,1385,106,1386,107,1387,108,1388,109,1389,110,1390,111,1391
dc.w 97,1377,97,1377,97,1377,97,1377,97,1377,97,1377,97,1377,97,1377
dc.w 97,1377,97,1377,97,1377,97,1377,97,1377,97,1377,97,1377,97,1377
dc.w 0,1408,0,1409,3,1410,0,1411,0,1412,6,1413,0,1414,8,1415
dc.w 9,1416,32,1417,10,1418,11,1419,12,1420,13,1421,14,1422,15,1423
dc.w 16,1424,17,1425,18,1426,19,1427,20,1428,21,1429,22,1430,23,1431
dc.w 24,1432,25,1433,26,1434,27,1435,28,1436,29,1437,30,1438,31,1439
dc.w 32,1440,33,1441,34,1442,35,1443,36,1444,37,1445,38,1446,39,1447
dc.w 40,1448,41,1449,42,1450,43,1451,44,1452,45,1453,46,1454,47,1455
dc.w 48,1456,49,1457,50,1458,51,1459,52,1460,53,1461,54,1462,55,1463
dc.w 56,1464,57,1465,58,1466,59,1467,60,1468,61,1469,62,1470,63,1471
dc.w 64,1472,65,1473,66,1474,67,1475,68,1476,69,1477,70,1478,71,1479
dc.w 72,1480,73,1481,74,1482,75,1483,76,1484,77,1485,78,1486,79,1487
dc.w 80,1488,81,1489,82,1490,83,1491,84,1492,85,1493,86,1494,87,1495
dc.w 88,1496,89,1497,90,1498,91,1499,92,1500,93,1501,94,1502,95,1503
dc.w 96,1504,97,1505,98,1506,99,1507,100,1508,101,1509,102,1510,103,1511
dc.w 104,1512,105,1513,106,1514,107,1515,108,1516,109,1517,110,1518,111,1519
dc.w 97,1505,97,1505,97,1505,97,1505,97,1505,97,1505,97,1505,97,1505
dc.w 97,1505,97,1505,97,1505,97,1505,97,1505,97,1505,97,1505,97,1505
dc.w 0,1536,0,1537,3,1538,0,1539,0,1540,6,1541,0,1542,8,1543
dc.w 9,1544,32,1545,10,1546,11,1547,12,1548,13,1549,14,1550,15,1551
dc.w 16,1552,17,1553,18,1554,19,1555,20,1556,21,1557,22,1558,23,1559
dc.w 24,1560,25,1561,26,1562,27,1563,28,1564,29,1565,30,1566,31,1567
dc.w 0,1568,0,1569,0,1570,36,1571,0,1572,0,1573,39,1574,0,1575
dc.w 41,1576,64,1577,42,1578,43,1579,44,1580,45,1581,46,1582,47,1583
dc.w 48,1584,49,1585,50,1586,51,1587,52,1588,53,1589,54,1590,55,1591
dc.w 56,1592,57,1593,58,1594,59,1595,60,1596,61,1597,62,1598,63,1599
dc.w 65,1600,0,1601,0,1602,0,1603,69,1604,0,1605,0,1606,72,1607
dc.w 0,1608,97,1609,74,1610,75,1611,76,1612,77,1613,78,1614,79,1615
dc.w 80,1616,81,1617,82,1618,83,1619,84,1620,85,1621,86,1622,87,1623
dc.w 88,1624,89,1625,90,1626,91,1627,92,1628,93,1629,94,1630,95,1631
dc.w 99,1632,99,1633,101,1634,103,1635,105,1636,107,1637,109,1638,111,1639
dc.w 113,1640,115,1641,117,1642,119,1643,121,1644,123,1645,125,1646,127,1647
dc.w 99,1633,99,1633,99,1633,99,1633,99,1633,99,1633,99,1633,99,1633
dc.w 99,1633,99,1633,99,1633,99,1633,99,1633,99,1633,99,1633,99,1633
dc.w 0,1664,0,1665,3,1666,0,1667,0,1668,6,1669,0,1670,8,1671
dc.w 9,1672,32,1673,10,1674,11,1675,12,1676,13,1677,14,1678,15,1679
dc.w 16,1680,17,1681,18,1682,19,1683,20,1684,21,1685,22,1686,23,1687
dc.w 24,1688,25,1689,26,1690,27,1691,28,1692,29,1693,30,1694,31,1695
dc.w 0,1696,0,1697,0,1698,36,1699,0,1700,0,1701,39,1702,0,1703
dc.w 41,1704,64,1705,42,1706,43,1707,44,1708,45,1709,46,1710,47,1711
dc.w 48,1712,49,1713,50,1714,51,1715,52,1716,53,1717,54,1718,55,1719
dc.w 56,1720,57,1721,58,1722,59,1723,60,1724,61,1725,62,1726,63,1727
dc.w 65,1728,0,1729,0,1730,0,1731,69,1732,0,1733,0,1734,72,1735
dc.w 0,1736,97,1737,74,1738,75,1739,76,1740,77,1741,78,1742,79,1743
dc.w 80,1744,81,1745,82,1746,83,1747,84,1748,85,1749,86,1750,87,1751
dc.w 88,1752,89,1753,90,1754,91,1755,92,1756,93,1757,94,1758,95,1759
dc.w 99,1760,99,1761,101,1762,103,1763,105,1764,107,1765,109,1766,111,1767
dc.w 113,1768,115,1769,117,1770,119,1771,121,1772,123,1773,125,1774,127,1775
dc.w 99,1761,99,1761,99,1761,99,1761,99,1761,99,1761,99,1761,99,1761
dc.w 99,1761,99,1761,99,1761,99,1761,99,1761,99,1761,99,1761,99,1761
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123



;tab with sync buffer
dc.w 128,1026,129,1026,130,1024,131,1028,132,1029,133,1024,134,1031,135,1024
dc.w 136,1024,137,1024,138,1034,139,1035,140,1036,141,1037,142,1038,143,1039
dc.w 144,1040,145,1041,146,1042,147,1043,148,1044,149,1045,150,1046,151,1047
dc.w 152,1048,153,1049,154,1050,155,1051,156,1052,157,1053,158,1054,159,1055
dc.w 160,1056,161,1057,162,1058,163,1059,164,1060,165,1061,166,1062,167,1063
dc.w 168,1064,169,1065,170,1066,171,1067,172,1068,173,1069,174,1070,175,1071
dc.w 176,1072,177,1073,178,1074,179,1075,180,1076,181,1077,182,1078,183,1079
dc.w 184,1080,185,1081,186,1082,187,1083,188,1084,189,1085,190,1086,191,1087
dc.w 192,1088,193,1089,194,1090,195,1091,196,1092,197,1093,198,1094,199,1095
dc.w 200,1096,201,1097,202,1098,203,1099,204,1100,205,1101,206,1102,207,1103
dc.w 208,1104,209,1105,210,1106,211,1107,212,1108,213,1109,214,1110,215,1111
dc.w 216,1112,217,1113,218,1114,219,1115,220,1116,221,1117,222,1118,223,1119
dc.w 224,1120,225,1121,226,1122,227,1123,228,1124,229,1125,230,1126,231,1127
dc.w 232,1128,233,1129,234,1130,235,1131,236,1132,237,1133,238,1134,239,1135
dc.w 225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121
dc.w 225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121,225,1121
dc.w 256,1026,257,1026,258,1024,259,1028,260,1029,261,1024,262,1031,263,1024
dc.w 264,1024,265,1024,266,1034,267,1035,268,1036,269,1037,270,1038,271,1039
dc.w 272,1040,273,1041,274,1042,275,1043,276,1044,277,1045,278,1046,279,1047
dc.w 280,1048,281,1049,282,1050,283,1051,284,1052,285,1053,286,1054,287,1055
dc.w 288,1312,289,1313,290,1314,291,1315,292,1316,293,1317,294,1318,295,1319
dc.w 296,1320,297,1321,298,1322,299,1323,300,1324,301,1325,302,1326,303,1327
dc.w 304,1328,305,1329,306,1330,307,1331,308,1332,309,1333,310,1334,311,1335
dc.w 312,1336,313,1337,314,1338,315,1339,316,1340,317,1341,318,1342,319,1343
dc.w 320,1344,321,1345,322,1346,323,1347,324,1348,325,1349,326,1350,327,1351
dc.w 328,1352,329,1353,330,1354,331,1355,332,1356,333,1357,334,1358,335,1359
dc.w 336,1360,337,1361,338,1362,339,1363,340,1364,341,1365,342,1366,343,1367
dc.w 344,1368,345,1369,346,1370,347,1371,348,1372,349,1373,350,1374,351,1375
dc.w 352,1376,353,1377,354,1378,355,1379,356,1380,357,1381,358,1382,359,1383
dc.w 360,1384,361,1385,362,1386,363,1387,364,1388,365,1389,366,1390,367,1391
dc.w 353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377
dc.w 353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377
dc.w 384,1026,385,1026,386,1024,387,1028,388,1029,389,1024,390,1031,391,1024
dc.w 392,1024,393,1024,394,1034,395,1035,396,1036,397,1037,398,1038,399,1039
dc.w 400,1040,401,1041,402,1042,403,1043,404,1044,405,1045,406,1046,407,1047
dc.w 408,1048,409,1049,410,1050,411,1051,412,1052,413,1053,414,1054,415,1055
dc.w 416,1440,417,1441,418,1442,419,1443,420,1444,421,1445,422,1446,423,1447
dc.w 424,1448,425,1449,426,1450,427,1451,428,1452,429,1453,430,1454,431,1455
dc.w 432,1456,433,1457,434,1458,435,1459,436,1460,437,1461,438,1462,439,1463
dc.w 440,1464,441,1465,442,1466,443,1467,444,1468,445,1469,446,1470,447,1471
dc.w 448,1472,449,1473,450,1474,451,1475,452,1476,453,1477,454,1478,455,1479
dc.w 456,1480,457,1481,458,1482,459,1483,460,1484,461,1485,462,1486,463,1487
dc.w 464,1488,465,1489,466,1490,467,1491,468,1492,469,1493,470,1494,471,1495
dc.w 472,1496,473,1497,474,1498,475,1499,476,1500,477,1501,478,1502,479,1503
dc.w 480,1504,481,1505,482,1506,483,1507,484,1508,485,1509,486,1510,487,1511
dc.w 488,1512,489,1513,490,1514,491,1515,492,1516,493,1517,494,1518,495,1519
dc.w 481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505
dc.w 481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505
dc.w 512,1026,513,1026,514,1024,515,1028,516,1029,517,1024,518,1031,519,1024
dc.w 520,1024,521,1024,522,1034,523,1035,524,1036,525,1037,526,1038,527,1039
dc.w 528,1040,529,1041,530,1042,531,1043,532,1044,533,1045,534,1046,535,1047
dc.w 536,1048,537,1049,538,1050,539,1051,540,1052,541,1053,542,1054,543,1055
dc.w 544,544,545,545,546,546,547,547,548,548,549,549,550,550,551,551
dc.w 552,552,553,553,554,554,555,555,556,556,557,557,558,558,559,559
dc.w 560,560,561,561,562,562,563,563,564,564,565,565,566,566,567,567
dc.w 568,568,569,569,570,570,571,571,572,572,573,573,574,574,575,575
dc.w 576,576,577,577,578,578,579,579,580,580,581,581,582,582,583,583
dc.w 584,584,585,585,586,586,587,587,588,588,589,589,590,590,591,591
dc.w 592,592,593,593,594,594,595,595,596,596,597,597,598,598,599,599
dc.w 600,600,601,601,602,602,603,603,604,604,605,605,606,606,607,607
dc.w 608,608,609,609,610,610,611,611,612,612,613,613,614,614,615,615
dc.w 616,616,617,617,618,618,619,619,620,620,621,621,622,622,623,623
dc.w 609,609,609,609,609,609,609,609,609,609,609,609,609,609,609,609
dc.w 609,609,609,609,609,609,609,609,609,609,609,609,609,609,609,609
dc.w 640,1026,641,1026,642,1024,643,1028,644,1029,645,1024,646,1031,647,1024
dc.w 648,1024,649,1024,650,1034,651,1035,652,1036,653,1037,654,1038,655,1039
dc.w 656,1040,657,1041,658,1042,659,1043,660,1044,661,1045,662,1046,663,1047
dc.w 664,1048,665,1049,666,1050,667,1051,668,1052,669,1053,670,1054,671,1055
dc.w 672,672,673,673,674,674,675,675,676,676,677,677,678,678,679,679
dc.w 680,680,681,681,682,682,683,683,684,684,685,685,686,686,687,687
dc.w 688,688,689,689,690,690,691,691,692,692,693,693,694,694,695,695
dc.w 696,696,697,697,698,698,699,699,700,700,701,701,702,702,703,703
dc.w 704,704,705,705,706,706,707,707,708,708,709,709,710,710,711,711
dc.w 712,712,713,713,714,714,715,715,716,716,717,717,718,718,719,719
dc.w 720,720,721,721,722,722,723,723,724,724,725,725,726,726,727,727
dc.w 728,728,729,729,730,730,731,731,732,732,733,733,734,734,735,735
dc.w 736,736,737,737,738,738,739,739,740,740,741,741,742,742,743,743
dc.w 744,744,745,745,746,746,747,747,748,748,749,749,750,750,751,751
dc.w 737,737,737,737,737,737,737,737,737,737,737,737,737,737,737,737
dc.w 737,737,737,737,737,737,737,737,737,737,737,737,737,737,737,737
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 2,1026,2,1026,0,1024,4,1028,5,1029,0,1024,7,1031,0,1024
dc.w 0,1024,0,1024,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 33,1057,34,1058,35,1059,0,1024,37,1061,38,1062,0,1024,40,1064
dc.w 0,1024,0,1024,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 0,1024,66,1090,67,1091,68,1092,0,1024,70,1094,71,1095,0,1024
dc.w 73,1097,0,1024,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 98,1122,98,1122,100,1124,102,1126,104,1128,106,1130,108,1132,110,1134
dc.w 112,1136,114,1138,116,1140,118,1142,120,1144,122,1146,124,1148,126,1150
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122,98,1122
dc.w 0,1152,0,1153,3,1154,0,1155,0,1156,6,1157,0,1158,8,1159
dc.w 9,1160,32,1161,10,1162,11,1163,12,1164,13,1165,14,1166,15,1167
dc.w 16,1168,17,1169,18,1170,19,1171,20,1172,21,1173,22,1174,23,1175
dc.w 24,1176,25,1177,26,1178,27,1179,28,1180,29,1181,30,1182,31,1183
dc.w 32,1184,33,1185,34,1186,35,1187,36,1188,37,1189,38,1190,39,1191
dc.w 40,1192,41,1193,42,1194,43,1195,44,1196,45,1197,46,1198,47,1199
dc.w 48,1200,49,1201,50,1202,51,1203,52,1204,53,1205,54,1206,55,1207
dc.w 56,1208,57,1209,58,1210,59,1211,60,1212,61,1213,62,1214,63,1215
dc.w 64,1216,65,1217,66,1218,67,1219,68,1220,69,1221,70,1222,71,1223
dc.w 72,1224,73,1225,74,1226,75,1227,76,1228,77,1229,78,1230,79,1231
dc.w 80,1232,81,1233,82,1234,83,1235,84,1236,85,1237,86,1238,87,1239
dc.w 88,1240,89,1241,90,1242,91,1243,92,1244,93,1245,94,1246,95,1247
dc.w 96,1248,97,1249,98,1250,99,1251,100,1252,101,1253,102,1254,103,1255
dc.w 104,1256,105,1257,106,1258,107,1259,108,1260,109,1261,110,1262,111,1263
dc.w 97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249
dc.w 97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249,97,1249
dc.w 0,1280,0,1281,3,1282,0,1283,0,1284,6,1285,0,1286,8,1287
dc.w 9,1288,32,1289,10,1290,11,1291,12,1292,13,1293,14,1294,15,1295
dc.w 16,1296,17,1297,18,1298,19,1299,20,1300,21,1301,22,1302,23,1303
dc.w 24,1304,25,1305,26,1306,27,1307,28,1308,29,1309,30,1310,31,1311
dc.w 288,1312,289,1313,290,1314,291,1315,292,1316,293,1317,294,1318,295,1319
dc.w 296,1320,297,1321,298,1322,299,1323,300,1324,301,1325,302,1326,303,1327
dc.w 304,1328,305,1329,306,1330,307,1331,308,1332,309,1333,310,1334,311,1335
dc.w 312,1336,313,1337,314,1338,315,1339,316,1340,317,1341,318,1342,319,1343
dc.w 320,1344,321,1345,322,1346,323,1347,324,1348,325,1349,326,1350,327,1351
dc.w 328,1352,329,1353,330,1354,331,1355,332,1356,333,1357,334,1358,335,1359
dc.w 336,1360,337,1361,338,1362,339,1363,340,1364,341,1365,342,1366,343,1367
dc.w 344,1368,345,1369,346,1370,347,1371,348,1372,349,1373,350,1374,351,1375
dc.w 352,1376,353,1377,354,1378,355,1379,356,1380,357,1381,358,1382,359,1383
dc.w 360,1384,361,1385,362,1386,363,1387,364,1388,365,1389,366,1390,367,1391
dc.w 353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377
dc.w 353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377,353,1377
dc.w 0,1408,0,1409,3,1410,0,1411,0,1412,6,1413,0,1414,8,1415
dc.w 9,1416,32,1417,10,1418,11,1419,12,1420,13,1421,14,1422,15,1423
dc.w 16,1424,17,1425,18,1426,19,1427,20,1428,21,1429,22,1430,23,1431
dc.w 24,1432,25,1433,26,1434,27,1435,28,1436,29,1437,30,1438,31,1439
dc.w 416,1440,417,1441,418,1442,419,1443,420,1444,421,1445,422,1446,423,1447
dc.w 424,1448,425,1449,426,1450,427,1451,428,1452,429,1453,430,1454,431,1455
dc.w 432,1456,433,1457,434,1458,435,1459,436,1460,437,1461,438,1462,439,1463
dc.w 440,1464,441,1465,442,1466,443,1467,444,1468,445,1469,446,1470,447,1471
dc.w 448,1472,449,1473,450,1474,451,1475,452,1476,453,1477,454,1478,455,1479
dc.w 456,1480,457,1481,458,1482,459,1483,460,1484,461,1485,462,1486,463,1487
dc.w 464,1488,465,1489,466,1490,467,1491,468,1492,469,1493,470,1494,471,1495
dc.w 472,1496,473,1497,474,1498,475,1499,476,1500,477,1501,478,1502,479,1503
dc.w 480,1504,481,1505,482,1506,483,1507,484,1508,485,1509,486,1510,487,1511
dc.w 488,1512,489,1513,490,1514,491,1515,492,1516,493,1517,494,1518,495,1519
dc.w 481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505
dc.w 481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505,481,1505
dc.w 0,1536,0,1537,3,1538,0,1539,0,1540,6,1541,0,1542,8,1543
dc.w 9,1544,32,1545,10,1546,11,1547,12,1548,13,1549,14,1550,15,1551
dc.w 16,1552,17,1553,18,1554,19,1555,20,1556,21,1557,22,1558,23,1559
dc.w 24,1560,25,1561,26,1562,27,1563,28,1564,29,1565,30,1566,31,1567
dc.w 1568,1568,1569,1569,1570,1570,1571,1571,1572,1572,1573,1573,1574,1574,1575,1575
dc.w 1576,1576,1577,1577,1578,1578,1579,1579,1580,1580,1581,1581,1582,1582,1583,1583
dc.w 1584,1584,1585,1585,1586,1586,1587,1587,1588,1588,1589,1589,1590,1590,1591,1591
dc.w 1592,1592,1593,1593,1594,1594,1595,1595,1596,1596,1597,1597,1598,1598,1599,1599
dc.w 1600,1600,1601,1601,1602,1602,1603,1603,1604,1604,1605,1605,1606,1606,1607,1607
dc.w 1608,1608,1609,1609,1610,1610,1611,1611,1612,1612,1613,1613,1614,1614,1615,1615
dc.w 1616,1616,1617,1617,1618,1618,1619,1619,1620,1620,1621,1621,1622,1622,1623,1623
dc.w 1624,1624,1625,1625,1626,1626,1627,1627,1628,1628,1629,1629,1630,1630,1631,1631
dc.w 1632,1632,1633,1633,1634,1634,1635,1635,1636,1636,1637,1637,1638,1638,1639,1639
dc.w 1640,1640,1641,1641,1642,1642,1643,1643,1644,1644,1645,1645,1646,1646,1647,1647
dc.w 1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633
dc.w 1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633,1633
dc.w 0,1664,0,1665,3,1666,0,1667,0,1668,6,1669,0,1670,8,1671
dc.w 9,1672,32,1673,10,1674,11,1675,12,1676,13,1677,14,1678,15,1679
dc.w 16,1680,17,1681,18,1682,19,1683,20,1684,21,1685,22,1686,23,1687
dc.w 24,1688,25,1689,26,1690,27,1691,28,1692,29,1693,30,1694,31,1695
dc.w 1696,1696,1697,1697,1698,1698,1699,1699,1700,1700,1701,1701,1702,1702,1703,1703
dc.w 1704,1704,1705,1705,1706,1706,1707,1707,1708,1708,1709,1709,1710,1710,1711,1711
dc.w 1712,1712,1713,1713,1714,1714,1715,1715,1716,1716,1717,1717,1718,1718,1719,1719
dc.w 1720,1720,1721,1721,1722,1722,1723,1723,1724,1724,1725,1725,1726,1726,1727,1727
dc.w 1728,1728,1729,1729,1730,1730,1731,1731,1732,1732,1733,1733,1734,1734,1735,1735
dc.w 1736,1736,1737,1737,1738,1738,1739,1739,1740,1740,1741,1741,1742,1742,1743,1743
dc.w 1744,1744,1745,1745,1746,1746,1747,1747,1748,1748,1749,1749,1750,1750,1751,1751
dc.w 1752,1752,1753,1753,1754,1754,1755,1755,1756,1756,1757,1757,1758,1758,1759,1759
dc.w 1760,1760,1761,1761,1762,1762,1763,1763,1764,1764,1765,1765,1766,1766,1767,1767
dc.w 1768,1768,1769,1769,1770,1770,1771,1771,1772,1772,1773,1773,1774,1774,1775,1775
dc.w 1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761
dc.w 1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761,1761
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 0,1024,0,1024,3,1027,0,1024,0,1024,6,1030,0,1024,8,1032
dc.w 9,1033,32,1056,10,1034,11,1035,12,1036,13,1037,14,1038,15,1039
dc.w 16,1040,17,1041,18,1042,19,1043,20,1044,21,1045,22,1046,23,1047
dc.w 24,1048,25,1049,26,1050,27,1051,28,1052,29,1053,30,1054,31,1055
dc.w 0,1024,0,1024,0,1024,36,1060,0,1024,0,1024,39,1063,0,1024
dc.w 41,1065,64,1088,42,1066,43,1067,44,1068,45,1069,46,1070,47,1071
dc.w 48,1072,49,1073,50,1074,51,1075,52,1076,53,1077,54,1078,55,1079
dc.w 56,1080,57,1081,58,1082,59,1083,60,1084,61,1085,62,1086,63,1087
dc.w 65,1089,0,1024,0,1024,0,1024,69,1093,0,1024,0,1024,72,1096
dc.w 0,1024,97,1121,74,1098,75,1099,76,1100,77,1101,78,1102,79,1103
dc.w 80,1104,81,1105,82,1106,83,1107,84,1108,85,1109,86,1110,87,1111
dc.w 88,1112,89,1113,90,1114,91,1115,92,1116,93,1117,94,1118,95,1119
dc.w 99,1123,99,1123,101,1125,103,1127,105,1129,107,1131,109,1133,111,1135
dc.w 113,1137,115,1139,117,1141,119,1143,121,1145,123,1147,125,1149,127,1151
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123
dc.w 99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123,99,1123

rawtab:		blk.b	38			;raw data
vantab:		blk.w	152,0			;vanilla data

;*****************************************************************************
